@@ -1,11 +1,11 @@
 /*
  *  agShell
- *  $Id: agShell.c,v 1.15 2001/10/20 14:54:39 bkorb Exp $
+ *  $Id: agShell.c,v 3.7 2002/02/03 01:34:13 bkorb Exp $
  *  Manage a server shell process
  */
 
 /*
- *  AutoGen copyright 1992-1999 Bruce Korb
+ *  AutoGen copyright 1992-2002 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -38,24 +38,41 @@
 #  include <sys/procset.h>
 #endif
 
+tSCC   zTxtBlock[] = "Text Block";
+
+#ifndef SHELL_ENABLED
+ void closeServer( void ) { }
+
+ int chainOpen( int stdinFd, tCC** ppArgs, pid_t* pChild ) { return -1; }
+
+ pid_t openServer( tFdPair* pPair, tCC** ppArgs ) { return NOPROCESS; }
+
+ pid_t openServerFP( tpfPair* pfPair, tCC** ppArgs ) { return NOPROCESS; }
+
+ char* runShell( const char* pzCmd ) {
+     char* pz;
+     AGDUPSTR( pz, pzCmd, "dummy shell command" );
+     return pz;
+ }
+#else
+
 /*
  *  Dual pipe opening of a child process
  */
-STATIC tpfPair serverPair = { (FILE*)NULL, (FILE*)NULL };
+STATIC tpfPair serverPair = { NULL, NULL };
 STATIC pid_t   serverId   = NULLPROCESS;
-STATIC tpChar  pCurDir    = (char*)NULL;
+STATIC tpChar  pCurDir    = NULL;
 STATIC ag_bool errClose   = AG_FALSE;
 
-tSCC   zTxtBlock[] = "Text Block";
 tSCC   zCmdFmt[]   = "cd %s\n%s\n\necho\necho %s\n";
 
-const char* pzLastCmd = (const char*)NULL;
+const char* pzLastCmd = NULL;
 
 STATIC void sigHandler( int signo );
 STATIC void serverSetup( void );
 
 
-    EXPORT void
+EXPORT void
 closeServer( void )
 {
     if (serverId == NULLPROCESS)
@@ -75,30 +92,30 @@ closeServer( void )
         (void)fclose( serverPair.pfWrite );
     }
 
-    serverPair.pfRead = serverPair.pfWrite = (FILE*)NULL;
+    serverPair.pfRead = serverPair.pfWrite = NULL;
 }
 
 
-    STATIC void
+STATIC void
 sigHandler( int signo )
 {
     extern char* strsignal PROTO(( int ));
-    fprintf( stderr, "Closing server:  %s signal (%d) received\n",
+    fprintf( pfTrace, "Closing server:  %s signal (%d) received\n",
              strsignal( signo ), signo );
     errClose = AG_TRUE;
 
-    (void)fputs( "\nLast command issued:\n", stderr );
+    (void)fputs( "\nLast command issued:\n", pfTrace );
     {
-        const char* pz = (pzLastCmd == (const char*)NULL)
+        const char* pz = (pzLastCmd == NULL)
             ? "?? unknown ??\n" : pzLastCmd;
-        fprintf( stderr, zCmdFmt, pCurDir, pz, zShDone );
+        fprintf( pfTrace, zCmdFmt, pCurDir, pz, zShDone );
     }
-    pzLastCmd = (const char*)NULL;
+    pzLastCmd = NULL;
     closeServer();
 }
 
 
-    STATIC void
+STATIC void
 serverSetup( void )
 {
     struct sigaction  saNew;
@@ -109,13 +126,13 @@ serverSetup( void )
         static int doneOnce = 0;
         if (doneOnce++ == 0) {
             (void)atexit( &closeServer );
-            pCurDir = getcwd( (char*)NULL, MAXPATHLEN+1 );
-#if defined( DEBUG ) && defined( VALUE_OPT_SHOW_SHELL )
+            pCurDir = getcwd( NULL, MAXPATHLEN+1 );
+#if defined( DEBUG )
             if (HAVE_OPT( SHOW_SHELL ))
-                fputs( "\nServer First Start\n", stderr );
+                fputs( "\nServer First Start\n", pfTrace );
         }
         else {
-            fputs( "\nServer Restart\n", stderr );
+            fputs( "\nServer Restart\n", pfTrace );
 #endif
         }
     }
@@ -143,9 +160,9 @@ serverSetup( void )
                  pzLastCmd, zShDone );
         (void)fflush( serverPair.pfWrite );
         pz = loadData( serverPair.pfRead );
-#if defined( DEBUG ) && defined( VALUE_OPT_SHOW_SHELL )
+#if defined( DEBUG )
         if (HAVE_OPT( SHOW_SHELL ) && (*pz != NUL))
-            fprintf( stderr, "Trap set result:  `%s'\n", pz );
+            fprintf( pfTrace, "Trap set result:  `%s'\n", pz );
         AGFREE( (void*)pz );
     }
 
@@ -156,16 +173,16 @@ serverSetup( void )
                         "echo server setup done\n";
         char* pz;
 
-        fputs( "Server traps set\n", stderr );
+        fputs( "Server traps set\n", pfTrace );
         pzLastCmd = zSetup;
         fprintf( serverPair.pfWrite, zCmdFmt, pCurDir, pzLastCmd, zShDone );
         (void)fflush( serverPair.pfWrite );
         pz = loadData( serverPair.pfRead );
-        fprintf( stderr, "Trap state:\n%s\n", pz );
+        fprintf( pfTrace, "Trap state:\n%s\n", pz );
 #endif
         AGFREE( (void*)pz );
     }
-    pzLastCmd = (const char*)NULL;
+    pzLastCmd = NULL;
 }
 
 
@@ -178,7 +195,7 @@ serverSetup( void )
  *  for the new process and, optionally, a pointer to a place
  *  to store the child's process id.
  */
-    EXPORT int
+EXPORT int
 chainOpen( int       stdinFd,
            tCC**     ppArgs,
            pid_t*    pChild  )
@@ -190,7 +207,7 @@ chainOpen( int       stdinFd,
     /*
      *  If we did not get an arg list, use the default
      */
-    if (ppArgs == (tCC**)NULL)
+    if (ppArgs == NULL)
         ppArgs = serverArgs;
 
     /*
@@ -199,10 +216,10 @@ chainOpen( int       stdinFd,
      *  that, then sh.  Set argv[0] to whatever we decided on.
      */
     if (pzShell = *ppArgs,
-       (pzShell == (char*)NULL) || (*pzShell == NUL)){
+       (pzShell == NULL) || (*pzShell == NUL)){
 
         pzShell = getenv( "SHELL" );
-        if (pzShell == (char*)NULL)
+        if (pzShell == NULL)
             pzShell = "sh";
 
         *ppArgs = pzShell;
@@ -213,26 +230,26 @@ chainOpen( int       stdinFd,
      *  and the parent will read from it.
      */
     if (pipe( (int*)&stdoutPair ) < 0) {
-        if (pChild != (pid_t*)NULL)
+        if (pChild != NULL)
             *pChild = NOPROCESS;
         return -1;
     }
 
-#if defined( DEBUG ) && defined( VALUE_OPT_SHOW_SHELL )
+#if defined( DEBUG )
     if (HAVE_OPT( SHOW_SHELL )) {
         tSCC   zPath[] = "PATH";
         tCC*   pzPath  = getenv( zPath );
 
-        if (pzPath == (char*)NULL)
+        if (pzPath == NULL)
             pzPath = pzShell;
 
         else {
             pzPath = pathfind( pzPath, pzShell, "rxs" );
-            if (pzPath == (char*)NULL)
+            if (pzPath == NULL)
                 pzPath = pzShell;
         }
 
-        fprintf( stderr, "Starting shell `%s'\n", pzPath );
+        fprintf( pfTrace, "Starting shell `%s'\n", pzPath );
     }
 #endif
     fflush( stdout );
@@ -247,19 +264,19 @@ chainOpen( int       stdinFd,
         close( stdinFd );
         close( stdoutPair.readFd );
         close( stdoutPair.writeFd );
-        if (pChild != (pid_t*)NULL)
+        if (pChild != NULL)
             *pChild = NOPROCESS;
         return -1;
 
     default:           /* parent - return opposite FD's */
-        if (pChild != (pid_t*)NULL)
+        if (pChild != NULL)
             *pChild = chId;
 
         close( stdinFd );
         close( stdoutPair.writeFd );
 #if defined( DEBUG )
         if (HAVE_OPT( SHOW_SHELL ))
-            fprintf( stderr, "Server shell is pid %d\n", chId );
+            fprintf( pfTrace, "Server shell is pid %d\n", chId );
 #endif
         return stdoutPair.readFd;
 
@@ -289,16 +306,15 @@ chainOpen( int       stdinFd,
      *  Make the output file unbuffered only.
      *  We do not want to wait for shell output buffering.
      */
-    setvbuf( stdout, (char*)NULL, _IONBF, 0 );
+    setvbuf( stdout, NULL, _IONBF, 0 );
 
 #if defined( DEBUG )
     if (HAVE_OPT( SHOW_SHELL ))
-        fprintf( stderr, "Server shell %s starts\n", pzShell );
+        fprintf( pfTrace, "Server shell %s starts\n", pzShell );
 #endif
     execvp( (char*)pzShell, (char**)ppArgs );
-    fprintf( stderr, "Error %d:  Could not execvp( '%s', ... ):  %s\n",
-             errno, pzShell, strerror( errno ));
-    AG_ABEND;
+    AG_ABEND( asprintf( "Could not execvp( '%s', ... ):  %d - %s\n",
+                        pzShell, errno, strerror( errno )));
 }
 
 
@@ -312,7 +328,7 @@ chainOpen( int       stdinFd,
  *  process should write to "writeFd" and read from "readFd".
  *  The return value is the process id of the created process.
  */
-    EXPORT pid_t
+EXPORT pid_t
 openServer( tFdPair* pPair, tCC** ppArgs )
 {
     pid_t     chId;
@@ -339,7 +355,7 @@ openServer( tFdPair* pPair, tCC** ppArgs )
  *  Identical to "openServer()", except that the "fd"'s are "fdopen(3)"-ed
  *  into file pointers instead.
  */
-    EXPORT pid_t
+EXPORT pid_t
 openServerFP( tpfPair* pfPair, tCC** ppArgs )
 {
     tFdPair   fdPair;
@@ -352,6 +368,7 @@ openServerFP( tpfPair* pfPair, tCC** ppArgs )
     pfPair->pfWrite = fdopen( fdPair.writeFd, "w" FOPEN_TEXT_FLAG );
     return chId;
 }
+#endif /* SHELL_ENABLED */
 
 
 /*
@@ -362,7 +379,7 @@ openServerFP( tpfPair* pfPair, tCC** ppArgs )
  *  The read data are stored in a malloc-ed string that is truncated
  *  to size at the end.  Input is assumed to be an ASCII string.
  */
-    EXPORT char*
+EXPORT char*
 loadData( FILE* fp )
 {
     char*   pzText;
@@ -378,17 +395,19 @@ loadData( FILE* fp )
 
     for (;;) {
         size_t  usedCt;
-
+#ifdef OPT_VALUE_TIMEOUT
         /*
          *  Set a timeout so we do not wait forever.
          */
         alarm( OPT_VALUE_TIMEOUT );
-
-        if (fgets( zLine, sizeof( zLine ), fp ) == (char*)NULL)
+        if (fgets( zLine, sizeof( zLine ), fp ) == NULL)
             break;
-
         alarm( 0 );
 
+#else
+        if (fgets( zLine, sizeof( zLine ), fp ) == NULL)
+            break;
+#endif
         /*
          *  Check for magic character sequence indicating 'DONE'
          */
@@ -416,11 +435,9 @@ loadData( FILE* fp )
             void*  p;
             textSize += 4096;
             p = AGREALOC( (void*)pzText, textSize, NULL );
-            if (p == (void*)NULL) {
-                fprintf( stderr, zAllocErr, pzProg,
-                         textSize, "Realloc Text Block" );
-                AGFREE( (void*)pzText );
-                return (char*)NULL;
+            if (p == NULL) {
+                tSCC zRTB[] = "Realloc Text Block";
+                AG_ABEND( asprintf( zAllocWhat, textSize, zRTB ));
             }
 
             pzText   = (char*)p;
@@ -438,14 +455,14 @@ loadData( FILE* fp )
                      "resizing text output" );
 }
 
-
+#ifdef SHELL_ENABLED
 /*
  *  Run a semi-permanent server shell.  The program will be the
  *  one named by the environment variable $SHELL, or default to "sh".
  *  If one of the commands we send to it takes too long or it dies,
  *  we will shoot it and restart one later.
  */
-    EXPORT char*
+EXPORT char*
 runShell( const char*  pzCmd )
 {
     tSCC zCmdFail[] = "CLOSING SHELL SERVER - command failure:\n\t%s\n";
@@ -477,18 +494,18 @@ runShell( const char*  pzCmd )
      *  have it output a special marker that we can find.
      */
     pzLastCmd = pzCmd;
-#if defined( DEBUG ) && defined( VALUE_OPT_SHOW_SHELL )
+#if defined( DEBUG )
     if (HAVE_OPT( SHOW_SHELL )) {
-        fputc( '\n', stderr );
-        fprintf( stderr, zCmdFmt, pCurDir, pzCmd, zShDone );
+        fputc( '\n', pfTrace );
+        fprintf( pfTrace, zCmdFmt, pCurDir, pzCmd, zShDone );
     }
 #endif
     fprintf( serverPair.pfWrite, zCmdFmt, pCurDir, pzCmd, zShDone );
     fflush( serverPair.pfWrite );
 
     if (errClose) {
-        fprintf( stderr, zCmdFail, pzCmd );
-        return (char*)NULL;
+        fprintf( pfTrace, zCmdFail, pzCmd );
+        return NULL;
     }
 
     /*
@@ -497,20 +514,22 @@ runShell( const char*  pzCmd )
      */
     {
         char* pz = loadData( serverPair.pfRead );
-        if (pz == (char*)NULL) {
-            fprintf( stderr, zCmdFail, pzCmd );
+        if (pz == NULL) {
+            fprintf( pfTrace, zCmdFail, pzCmd );
             closeServer();
             pz = (char*)AGALOC( 1, zTxtBlock );
 
             *pz = NUL;
 
         } else if (errClose)
-            fprintf( stderr, zCmdFail, pzCmd );
+            fprintf( pfTrace, zCmdFail, pzCmd );
 
-        pzLastCmd = (char*)NULL;
+        pzLastCmd = NULL;
         return pz;
     }
 }
+
+#endif /* ! SHELL_ENABLED */
 /*
  * Local Variables:
  * c-file-style: "stroustrup"
