@@ -1,12 +1,12 @@
 
 /*
  *  agUtils.c
- *  $Id: agUtils.c,v 1.19 2001/12/01 22:20:18 bkorb Exp $
+ *  $Id: agUtils.c,v 3.5 2002/01/19 07:35:23 bkorb Exp $
  *  This is the main routine for autogen.
  */
 
 /*
- *  AutoGen copyright 1992-1999 Bruce Korb
+ *  AutoGen copyright 1992-2002 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -78,7 +78,7 @@ strlcpy( char* dest, tCC* src, size_t n )
 #endif
 
 
-    EXPORT void
+EXPORT void
 doOptions( int arg_ct, char** arg_vec )
 {
     /*
@@ -121,10 +121,8 @@ doOptions( int arg_ct, char** arg_vec )
      *  THEN a template *must* have been specified.
      */
     if (  (! ENABLED_OPT( DEFINITIONS ))
-       && (! HAVE_OPT( OVERRIDE_TPL )) ) {
-        fputs( "AutoGen error:  no template was specified\n", stderr );
-        AG_ABEND;
-    }
+       && (! HAVE_OPT( OVERRIDE_TPL )) )
+        AG_ABEND( "no template was specified" );
 
     /*
      *  IF we do not have a base-name option, then we compute some value
@@ -143,7 +141,7 @@ doOptions( int arg_ct, char** arg_vec )
          *  Point to the character after the last '/', or to the full
          *  definition file name, if there is no '/'.
          */
-        if (pz++ == (char*)NULL)
+        if (pz++ == NULL)
             pz = OPT_ARG( DEFINITIONS );
 
         /*
@@ -179,7 +177,7 @@ doOptions( int arg_ct, char** arg_vec )
              *  IF there is no associated value,  THEN set it to '1'.
              *  There are weird problems with empty defines.
              */
-            if (strchr( pz, '=' ) == (char*)NULL) {
+            if (strchr( pz, '=' ) == NULL) {
                 size_t siz = strlen( pz )+3;
                 char*  p   = AGALOC( siz, "env define" );
                 strcpy( p, pz );
@@ -244,7 +242,7 @@ doOptions( int arg_ct, char** arg_vec )
 }
 
 
-    STATIC void
+STATIC void
 addSysEnv( char* pzEnvName )
 {
     tSCC zFmt[] = "%s=1";
@@ -267,7 +265,7 @@ addSysEnv( char* pzEnvName )
 }
 
 
-    EXPORT tCC*
+EXPORT tCC*
 getDefine( tCC* pzDefName )
 {
     char**  ppz;
@@ -281,22 +279,22 @@ getDefine( tCC* pzDefName )
             char* pzEq = strchr( pz, '=' );
             int   res;
 
-            if (pzEq != (char*)NULL)
+            if (pzEq != NULL)
                 *pzEq = NUL;
 
             res = strcmp( pzDefName, pz );
-            if (pzEq != (char*)NULL)
+            if (pzEq != NULL)
                 *pzEq = '=';
 
             if (res == 0)
-                return (pzEq != (char*)NULL) ? pzEq+1 : "";
+                return (pzEq != NULL) ? pzEq+1 : "";
         }
     }
     return getenv( pzDefName );
 }
 
 
-    EXPORT unsigned int
+EXPORT unsigned int
 doEscapeChar( tCC* pzIn, char* pRes )
 {
     unsigned int  res = 1;
@@ -414,7 +412,7 @@ doEscapeChar( tCC* pzIn, char* pRes )
  *  The quote character is whatever character the argument
  *  is pointing at when this procedure is called.
  */
-    EXPORT char*
+EXPORT char*
 spanQuote( char* pzQte )
 {
     char  q = *pzQte;          /*  Save the quote character type */
@@ -465,7 +463,7 @@ spanQuote( char* pzQte )
  *  The quote character is whatever character the argument
  *  is pointing at when this procedure is called.
  */
-    STATIC tCC*
+STATIC tCC*
 skipQuote( tCC* pzQte )
 {
     char  q = *pzQte++;        /*  Save the quote character type */
@@ -510,7 +508,7 @@ skipQuote( tCC* pzQte )
 }
 
 
-    EXPORT tCC*
+EXPORT tCC*
 skipScheme( tCC* pzSrc,  tCC* pzEnd )
 {
     int  level = 0;
@@ -535,7 +533,7 @@ skipScheme( tCC* pzSrc,  tCC* pzEnd )
 }
 
 
-    EXPORT tCC*
+EXPORT tCC*
 skipExpression( tCC* pzSrc, size_t len )
 {
     tCC* pzEnd = pzSrc + len;
@@ -548,7 +546,7 @@ skipExpression( tCC* pzSrc, size_t len )
     switch (*pzSrc) {
     case ';':
         pzSrc = strchr( pzSrc, '\n' );
-        if (pzSrc == (tCC*)NULL)
+        if (pzSrc == NULL)
             return pzEnd;
         goto guess_again;
 
@@ -577,10 +575,8 @@ skipExpression( tCC* pzSrc, size_t len )
 ag_alloc( size_t sz, tCC* pzWhat )
 {
     void* p = malloc( sz );
-    if ((p == (void*)NULL) && (pzWhat != NULL)) {
-        fprintf( stderr, zAllocErr, pzProg, sz, pzWhat );
-        LOAD_ABORT( pCurTemplate, pCurMacro, pzWhat );
-    }
+    if ((p == NULL) && (pzWhat != NULL))
+        AG_ABEND( asprintf( zAllocErr, pzProg, sz, pzWhat ));
     return p;
 }
 
@@ -589,11 +585,10 @@ ag_alloc( size_t sz, tCC* pzWhat )
 ag_realloc( void* p, size_t sz, tCC* pzWhat )
 {
     void* np = p ? realloc( p, sz ) : malloc( sz );
-    if (np == (void*)NULL) {
-        if (pzWhat != NULL) {
-            fprintf( stderr, zAllocErr, pzProg, sz, pzWhat );
-            LOAD_ABORT( pCurTemplate, pCurMacro, pzWhat );
-        }
+    if (np == NULL) {
+        if (pzWhat != NULL)
+            AG_ABEND( asprintf( zAllocErr, pzProg, sz, pzWhat ));
+
         if (p != NULL)
             free( p );
     }
@@ -620,14 +615,14 @@ ag_strdup( tCC* pz, tCC* pzWhat )
 
     pzRes = ag_alloc( len, pzWhat );
 
-    if (pzRes != (char*)NULL)
+    if (pzRes != NULL)
         strcpy( pzRes, pz );
 
     return pzRes;
 }
 
 #else
-STATIC tMemMgmt memHead = { &memHead, &memHead, (char*)NULL, "ROOT" };
+STATIC tMemMgmt memHead = { &memHead, &memHead, NULL, "ROOT" };
 #define CHECK_CT 128
 #define SPARE    128
 
@@ -638,12 +633,12 @@ ag_alloc( size_t sz, tCC* pzWhat, tCC* pz )
     size_t    asz = sz + sizeof( tMemMgmt ) + CHECK_CT + SPARE;
     tMemMgmt* p = (tMemMgmt*)malloc( asz & ~0x3F );
 
-    if (p == (tMemMgmt*)NULL) {
+    if (p == NULL) {
         if (pzWhat == NULL)
-            return (void*)NULL;
+            return NULL;
 
-        fprintf( stderr, zAllocErr, pzProg, sz, pzWhat );
-        LOAD_ABORT( pCurTemplate, pCurMacro, pzWhat );
+        pzWhat = asprintf( zAllocErr, pzProg, sz, pzWhat );
+        AG_ABEND( pzWhat );
     }
 
     /*
@@ -673,7 +668,7 @@ ag_realloc( void* p, size_t sz, tCC* pzWhat, tCC* pz )
     np = (tMemMgmt*)(p ? realloc( (void*)np, asz & ~0x3F )
                        : malloc( asz & ~0x3F ));
 
-    if (np == (tMemMgmt*)NULL) {
+    if (np == NULL) {
         if (pzWhat == NULL) {
             if (p != NULL)
                 free( (void*)p );
@@ -683,11 +678,10 @@ ag_realloc( void* p, size_t sz, tCC* pzWhat, tCC* pz )
              */
             sv.pPrev->pNext = sv.pNext;
             sv.pNext->pPrev = sv.pPrev;
-            return (void*)NULL;
+            return NULL;
         }
 
-        fprintf( stderr, zAllocErr, pzProg, sz, pzWhat );
-        LOAD_ABORT( pCurTemplate, pCurMacro, pzWhat );
+        AG_ABEND( asprintf( zAllocErr, pzProg, sz, pzWhat ));
     }
 
     /*
@@ -704,7 +698,7 @@ ag_realloc( void* p, size_t sz, tCC* pzWhat, tCC* pz )
 }
 
 
-    STATIC void
+STATIC void
 checkMem( tMemMgmt* pMM )
 {
     char* p  = pMM->pEnd;
@@ -712,12 +706,13 @@ checkMem( tMemMgmt* pMM )
 
     do  {
         if (*(p++) != '~') {
-            fprintf( stderr, "Stray pointer %d bytes after %d-byte %s end\n",
+            fprintf( pfTrace, "Stray pointer %d bytes after %d-byte %s end\n",
                      CHECK_CT - ct, pMM->pEnd - (char*)(pMM+1),
                      pMM->pzWhence );
             fclose( stderr );
+            fclose( pfTrace );
             fclose( stdout );
-            p = (char*)NULL;
+            p = NULL;
             *p = '~'; /* PAGE FAULT */
             _exit( EXIT_FAILURE );
         }
@@ -740,15 +735,15 @@ ag_free( void* p )
 }
 
 
-    STATIC void
+STATIC void
 finalMemCheck( void )
 {
     tMemMgmt*  pMM = memHead.pNext;
 
-    fputs( "\nResidual allocation list:\n", stderr );
+    fputs( "\nResidual allocation list:\n", pfTrace );
     while (pMM != &memHead) {
         checkMem( pMM );
-        fprintf( stderr, "%12d bytes from %s\n",
+        fprintf( pfTrace, "%12d bytes from %s\n",
                  pMM->pEnd - (char*)(pMM+1), pMM->pzWhence );
         pMM = pMM->pNext;
     }
@@ -773,7 +768,7 @@ ag_strdup( tCC* pz, tCC* pzDupFrom, tCC* pzWhat )
 
     pzRes = ag_alloc( len, pzWhat, pzDupFrom );
 
-    if (pzRes != (char*)NULL)
+    if (pzRes != NULL)
         strcpy( pzRes, pz );
 
     return pzRes;
