@@ -1,12 +1,12 @@
 
 /*
  *  autogen.h
- *  $Id: autogen.h,v 1.26 2001/08/29 03:11:24 bkorb Exp $
+ *  $Id: autogen.h,v 3.6 2002/01/31 02:29:13 bkorb Exp $
  *  Global header file for AutoGen
  */
 
 /*
- *  AutoGen copyright 1992-1999 Bruce Korb
+ *  AutoGen copyright 1992-2002 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -31,41 +31,25 @@
 #include "agUtils.h"
 #include "streqv.h"
 
-typedef enum {
-    PROC_STATE_INIT,       /* set up `atexit' and load Guile   */
-    PROC_STATE_OPTIONS,    /* processing command line options  */
-    PROC_STATE_GUILE_PRELOAD,
-    PROC_STATE_LOAD_DEFS,  /* Loading value definitions        */
-    PROC_STATE_LIB_LOAD,   /* Loading library template         */
-    PROC_STATE_LOAD_TPL,   /* Loading primary template         */
-    PROC_STATE_EMITTING,   /* processing templates             */
-    PROC_STATE_INCLUDING,  /* loading an included template     */
-    PROC_STATE_CLEANUP,
-    PROC_STATE_ABORTING,   /* Clean up code in error response  */
-    PROC_STATE_DONE        /* `exit' has been called           */
-} teProcState;
+#define STATE_TABLE           /* set up `atexit' and load Guile   */  \
+    _State_( INIT )           /* processing command line options  */  \
+    _State_( OPTIONS )        /* Loading guile at option time     */  \
+    _State_( GUILE_PRELOAD )  /* Loading value definitions        */  \
+    _State_( LOAD_DEFS )      /* Loading library template         */  \
+    _State_( LIB_LOAD )       /* Loading primary template         */  \
+    _State_( LOAD_TPL )       /* processing templates             */  \
+    _State_( EMITTING )       /* loading an included template     */  \
+    _State_( INCLUDING )      /* end of processing before exit()  */  \
+    _State_( CLEANUP )        /* Clean up code in error response  */  \
+    _State_( ABORTING )       /* `exit' has been called           */  \
+    _State_( DONE )
 
-#ifdef DEBUG
-#  define GIVE_UP(f,l) \
-    fprintf( stderr, zGiveUp, f, l )
-#else
-#  define GIVE_UP(f,l)
-#endif
+#define _State_(n)  PROC_STATE_ ## n,
+typedef enum { STATE_TABLE COUNT_PROC_STATE } teProcState;
+#undef _State_
 
 #define EXPORT
 
-#define AG_ABEND STMTS( \
-    GIVE_UP( __FILE__, __LINE__ ); \
-    if (procState < PROC_STATE_EMITTING) \
-        exit(EXIT_FAILURE); \
-    procState = PROC_STATE_ABORTING; \
-    longjmp( fileAbort, FAILURE ) )
-
-#define LOAD_ABORT( pT, pM, m ) STMTS( \
-    if (procState >= PROC_STATE_LIB_LOAD) \
-        fprintf( stderr, zTplErr, (pT)->pzFileName, (pM)->lineNo, m ); \
-    AG_ABEND )
-
 typedef struct fpStack       tFpStack;
 typedef struct outSpec       tOutSpec;
 typedef struct scanContext   tScanCtx;
@@ -76,7 +60,8 @@ typedef struct for_info      tForInfo;
 typedef struct for_state     tForState;
 typedef struct template_lib_marker tTlibMark;
 
-#define MAX_SUFFIX_LEN  8  /* maximum length of a file name suffix */
+#define MAX_SUFFIX_LEN    8  /* maximum length of a file name suffix */
+#define MAX_HEREMARK_LEN 64  /* max length of a here mark */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
@@ -152,11 +137,11 @@ struct template_desc {
     size_t      descSize;    /* Structure Size           */
     char*       pNext;       /* Next Pointer             */
     int         macroCt;     /* Count of Macros          */
-    char*       pzFileName;  /* Name of Macro File       */
+    tCC*        pzFileName;  /* Name of Macro File       */
     char*       pzTplName;   /* Template Name Pointer    */
     char*       pzTemplText; /* offset of the text       */
-    char        zStartMac[8];
-    char        zEndMac[8];
+    char        zStartMac[MAX_SUFFIX_LEN];
+    char        zEndMac[MAX_SUFFIX_LEN];
     tMacro      aMacros[1];  /* Array of Macros          */
 /*  char        text[...];    * strings at end of macros */
 };
@@ -254,23 +239,24 @@ struct for_state {
  */
 #define pzProg   autogenOptions.pzProgName
 MODE teProcState procState        VALUE( PROC_STATE_INIT );
-MODE char*       pzTemplFileName  VALUE( (char*)NULL );
-MODE tTemplate*  pNamedTplList    VALUE( (tTemplate*)NULL );
+MODE char*       pzTemplFileName  VALUE( NULL );
+MODE tTemplate*  pNamedTplList    VALUE( NULL );
+MODE tCC*        pzOopsPrefix     VALUE( "" );
 
 /*
  *  Template Processing Globals
  */
-MODE tCC*        pzCurSfx         VALUE( (char*)NULL );
+MODE tCC*        pzCurSfx         VALUE( NULL );
 MODE time_t      outTime          VALUE( 0 );
-MODE tFpStack*   pCurFp           VALUE( (tFpStack*)NULL );
-MODE tOutSpec*   pOutSpecList     VALUE( (tOutSpec*)NULL );
+MODE tFpStack*   pCurFp           VALUE( NULL );
+MODE tOutSpec*   pOutSpecList     VALUE( NULL );
 MODE jmp_buf     fileAbort        VALUE( { 0 } );
-MODE char*       pzCurStart       VALUE( (char*)NULL );
+MODE char*       pzCurStart       VALUE( NULL );
 MODE off_t       curStartOff      VALUE( 0 );
 MODE tForInfo    forInfo          VALUE( { 0 } );
-MODE FILE*       pfTrace          VALUE( (FILE*)NULL );
+MODE FILE*       pfTrace          VALUE( NULL );
 
-MODE tCC*        serverArgs[2]    VALUE( { (char*)NULL } );
+MODE tCC*        serverArgs[2]    VALUE( { NULL } );
 
 /*
  *  AutoGen definiton and template context
@@ -289,7 +275,7 @@ MODE tCC*        serverArgs[2]    VALUE( { (char*)NULL } );
  */
 MODE tDefStack   currDefCtx       VALUE( { NULL } );
 MODE tDefStack   rootDefCtx       VALUE( { NULL } );
-MODE tTemplate*  pCurTemplate     VALUE( (tTemplate*)NULL );
+MODE tTemplate*  pCurTemplate     VALUE( NULL );
 
 /*
  *  Current Macro
@@ -301,15 +287,15 @@ MODE tTemplate*  pCurTemplate     VALUE( (tTemplate*)NULL );
  *      alternation macros
  *  3.  mFunc_Case may transfer to one of its selection clauses.
  */
-MODE tMacro*     pCurMacro        VALUE( (tMacro*)NULL );
+MODE tMacro*     pCurMacro        VALUE( NULL );
 
 /*
  *  Template Parsing Globals
  */
 MODE int         templLineNo      VALUE( 1 );
-MODE tScanCtx*   pBaseCtx         VALUE( (tScanCtx*)NULL );
-MODE tScanCtx*   pCurCtx          VALUE( (tScanCtx*)NULL );
-MODE tScanCtx*   pDoneCtx         VALUE( (tScanCtx*)NULL );
+MODE tScanCtx*   pBaseCtx         VALUE( NULL );
+MODE tScanCtx*   pCurCtx          VALUE( NULL );
+MODE tScanCtx*   pDoneCtx         VALUE( NULL );
 MODE int         endMacLen        VALUE( 0  );
 MODE char        zEndMac[   8 ]   VALUE( "" );
 MODE int         startMacLen      VALUE( 0  );
@@ -318,7 +304,7 @@ MODE char        zStartMac[  8 ]  VALUE( "" );
 /*
  *  Definition Parsing Globals
  */
-MODE char*       pzDefineData     VALUE( (char*)NULL );
+MODE char*       pzDefineData     VALUE( NULL );
 MODE size_t      defineDataSize   VALUE( 0 );
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
@@ -328,15 +314,13 @@ MODE size_t      defineDataSize   VALUE( 0 );
 #define MKSTRING( name, val ) \
         MODE const char z ## name[ sizeof( val )] VALUE( val )
 
-MKSTRING( AllocErr,  "%s ERROR:  Couldn't allocate a %d byte %s\n" );
-MKSTRING( Cannot,    "%s ERROR %d: cannot %s %s:  %s\n" );
-MKSTRING( ShDone,    "ShElL-OuTpUt-HaS-bEeN-cOmPlEtEd" );
-MKSTRING( TplErr,    "Error in template %s, line %d\n\t%s\n" );
+MKSTRING( AllocWhat, "Could not allocate a %d byte %s\n" );
+MKSTRING( AllocErr,  "Allocation Failure" );
+MKSTRING( Cannot,    "fserr %d: cannot %s %s:  %s\n" );
 MKSTRING( TplWarn,   "Warning in template %s, line %d\n\t%s\n" );
 MKSTRING( FileLine,  "\tfrom %s line %d\n" );
-#ifdef DEBUG
-MKSTRING( GiveUp,    "Giving up in %s line %d\n" );
-#endif
+MKSTRING( ShDone,    "ShElL-OuTpUt-HaS-bEeN-cOmPlEtEd" );
+MKSTRING( NotStr,    "ERROR: %s is not a string\n" );
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
@@ -402,20 +386,26 @@ struct mem_mgmt {
 size_t strlcpy( char* dest, const char* src, size_t n );
 #endif
 
+#include "proto.h"
+
+#ifdef DEBUG
+# define AG_ABEND(s)  ag_abend_at(s,__FILE__,__LINE__)
+#else
+# define AG_ABEND(s)  ag_abend(s)
+#endif
+#define AG_ABEND_IN(t,m,s) \
+                      STMTS( pCurTemplate=(t); pCurMacro=(m); AG_ABEND(s);)
+
 static inline char* ag_scm2zchars( SCM s, tCC* type )
 {
-    if (! gh_string_p( s )) {
-        tSCC zNotStr[] = "ERROR: %s is not a string\n";
-        fprintf( stderr, zNotStr, type );
-        LOAD_ABORT( pCurTemplate, pCurMacro, zNotStr+14 );
-    }
+    if (! gh_string_p( s ))
+        AG_ABEND( asprintf( zNotStr, type ));
 
     if (SCM_SUBSTRP(s))
         s = scm_makfromstr( SCM_ROCHARS(s), SCM_ROLENGTH(s), 0 );
     return SCM_CHARS(s);
 }
 
-#include "proto.h"
 #endif /* AUTOGEN_HDR */
 /*
  * Local Variables:
