@@ -1,12 +1,12 @@
 
 /*
- *  $Id: defLex.c,v 1.22 2001/08/29 03:11:24 bkorb Exp $
+ *  $Id: defLex.c,v 3.5 2002/01/19 07:35:23 bkorb Exp $
  *  This module scans the template variable declarations and passes
  *  tokens back to the parser.
  */
 
 /*
- *  AutoGen copyright 1992-1999 Bruce Korb
+ *  AutoGen copyright 1992-2002 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -72,7 +72,7 @@ STATIC char* assembleHereString( char* pzScan );
  *
  *   LEXICAL SCANNER
  */
-    EXPORT int
+EXPORT int
 yylex( void )
 {
     lastToken = ERROR;
@@ -107,7 +107,7 @@ scanAgain:
          *  IF we are not inside an include context,
          *  THEN go finish.
          */
-        if (pCurCtx->pCtx == (tScanCtx*)NULL)
+        if (pCurCtx->pCtx == NULL)
             goto lex_done;
 
         /*
@@ -173,7 +173,7 @@ scanAgain:
     case '"':
     {
         char* pz = assembleString( pCurCtx->pzScan );
-        if (pz == (char*)NULL)
+        if (pz == NULL)
             goto NUL_error;
 
         lastToken = TK_STRING;
@@ -188,7 +188,7 @@ scanAgain:
             goto BrokenToken;
 
         pz = assembleHereString( pCurCtx->pzScan + 2 );
-        if (pz == (char*)NULL) {
+        if (pz == NULL) {
             lastToken = ERROR;
             return ERROR;
         }
@@ -211,7 +211,7 @@ scanAgain:
             char* pz = strchr( pCurCtx->pzScan, ';' );
 
             for (;;) {
-                if (pz == (char*)NULL) {
+                if (pz == NULL) {
                     pz = pCurCtx->pzScan + strlen( pCurCtx->pzScan );
                     break;
                 }
@@ -232,14 +232,14 @@ scanAgain:
     {
         char*   pz = assembleString( pCurCtx->pzScan );
 
-        if (pz == (char*)NULL)
+        if (pz == NULL)
             goto NUL_error;
 
         pCurCtx->pzScan = pz;
 
         lastToken = TK_STRING;
         pz = runShell( (const char*)yylval );
-        if (pz == (char*)NULL)
+        if (pz == NULL)
             goto scanAgain;
         TAGMEM( pz, "shell definition string" );
         yylval = (YYSTYPE)pz;
@@ -254,11 +254,11 @@ scanAgain:
         case '*':
         {
             char* pz = strstr( pCurCtx->pzScan+2, "*/" );
-            if (pz != (char*)NULL) {
+            if (pz != NULL) {
                 char* p = pCurCtx->pzScan+1;
                 for (;;) {
                     p = strchr( p+1, '\n' );
-                    if ((p == (char*)NULL) || (p > pz))
+                    if ((p == NULL) || (p > pz))
                         break;
                     pCurCtx->lineNo++;
                 }
@@ -270,7 +270,7 @@ scanAgain:
         case '/':
         {
             char* pz = strchr( pCurCtx->pzScan+2, '\n' );
-            if (pz != (char*)NULL) {
+            if (pz != NULL) {
                 pCurCtx->pzScan = pz+1;
                 goto scanAgain;
             }
@@ -289,9 +289,8 @@ scanAgain:
 
 NUL_error:
 
-    fprintf( stderr, zErrMsg, pzProg, "unterminated quote in definition",
-             pCurCtx->pzFileName, pCurCtx->lineNo );
-    lastToken = ERROR;
+    AG_ABEND( asprintf( zErrMsg, pzProg, "unterminated quote in definition",
+                        pCurCtx->pzFileName, pCurCtx->lineNo ));
     return ERROR;
 
 lex_done:
@@ -316,54 +315,40 @@ lex_done:
 
 
 
-    EXPORT void
+EXPORT void
 yyerror( char* s )
 {
-    fprintf( stderr, "%s:  in %s on line %d\n    token in error:  ",
-             s, pCurCtx->pzFileName, pCurCtx->lineNo );
+    tSCC zVN[] = "VAR_NAME %s\n";
+    tSCC zON[] = "OTHER_NAME %s\n";
+    tSCC zSt[] = "STRING %s\n";
+    tSCC zNo[] = "NUMBER %s\n";
+    tSCC zDf[] = "`%1$c' (%1$d)\n";
+
+    char* pz;
 
     if (strlen( pCurCtx->pzScan ) > 64 )
         pCurCtx->pzScan[64] = NUL;
 
     switch (lastToken) {
-    case TK_AUTOGEN:
-        fputs( "AUTOGEN\n", stderr );
-        break;
-
-    case TK_DEFINITIONS:
-        fputs( "DEFINITIONS\n", stderr );
-        break;
-
-    case TK_END:
-        fputs( "END\n", stderr );
-        break;
-
-    case TK_VAR_NAME:
-        fprintf( stderr, "VAR_NAME %s\n", (char*)yylval );
-        break;
-
-    case TK_OTHER_NAME:
-        fprintf( stderr, "OTHER_NAME %s\n", (char*)yylval );
-        break;
-
-    case TK_STRING:
-        fprintf( stderr, "STRING %s\n", (char*)yylval );
-        break;
-
-    case TK_NUMBER:
-        fprintf( stderr, "NUMBER %s\n", (char*)yylval );
-        break;
-
-    default:
-        fprintf( stderr, "`%1$c' (%1$d)\n", lastToken );
+    case TK_AUTOGEN:     pz = "AUTOGEN\n";     break;
+    case TK_DEFINITIONS: pz = "DEFINITIONS\n"; break;
+    case TK_END:         pz = "END\n";         break;
+    case TK_VAR_NAME:    pz = asprintf( zVN, (char*)yylval ); break;
+    case TK_OTHER_NAME:  pz = asprintf( zON, (char*)yylval ); break;
+    case TK_STRING:      pz = asprintf( zSt, (char*)yylval ); break;
+    case TK_NUMBER:      pz = asprintf( zNo, (char*)yylval ); break;
+    default:             pz = asprintf( zDf, lastToken );     break;
     }
 
-    fprintf( stderr, "\n[[...<error-text>]] %s\n\n", pCurCtx->pzScan );
-    AG_ABEND;
+    AG_ABEND( asprintf( "%s:  in %s on line %d\n"
+                        "\ttoken in error:  %s\n"
+                        "\t[[...<error-text>]] %s\n\n",
+                        s, pCurCtx->pzFileName, pCurCtx->lineNo, pz,
+                        pCurCtx->pzScan ));
 }
 
 
-    STATIC void
+STATIC void
 loadScheme( void )
 {
     char*    pzText    = pCurCtx->pzScan;
@@ -405,7 +390,7 @@ loadScheme( void )
  *  process a single scheme expression, yielding text that gets processed
  *  into AutoGen definitions.
  */
-    STATIC void
+STATIC void
 alist_to_autogen_def( void )
 {
     tSCC   zSchemeText[] = "Scheme Computed Definitions";
@@ -444,9 +429,8 @@ alist_to_autogen_def( void )
      *  The result *must* be a string, or we choke.
      */
     if (! gh_string_p( res )) {
-        tSCC zEr[] = "Error:  Scheme expression does not yield string:\n";
-        fputs( zEr, stderr );
-        AG_ABEND;
+        tSCC zEr[] = "Scheme definition expression does not yield string:\n";
+        AG_ABEND( zEr );
     }
 
     res_len   = SCM_LENGTH( res );
@@ -458,7 +442,7 @@ alist_to_autogen_def( void )
      *  Now, push the resulting string onto the input stack
      *  and link the new scan data into the context stack
      */
-    pCtx = (tScanCtx*)AGALOC( sizeof( tScanCtx ) + 4 + res_len, "lex scan ctx" );
+    pCtx = (tScanCtx*)AGALOC( sizeof(tScanCtx) + 4 + res_len, "lex scan ctx" );
     pCtx->pCtx  = pCurCtx;
     pCurCtx     = pCtx;
 
@@ -486,7 +470,7 @@ alist_to_autogen_def( void )
  *  It may be a number, a name, a keyword or garbage.
  *  Figure out which.
  */
-    STATIC char*
+STATIC char*
 assembleName( char* pzScan, YYSTYPE* pRetVal )
 {
     /*
@@ -547,13 +531,11 @@ assembleName( char* pzScan, YYSTYPE* pRetVal )
          *  ELSE skip over the rest of the OTHER_NAME
          */
         if (zNameChars[ *pz ] == 0) {
-            if (pz == (unsigned char*)pzScan) {
-                fprintf( stderr, "%s Error: Invalid input char '%c' "
-                         "in %s on line %d\n", pzProg, *pzScan,
-                         pCurCtx->pzFileName, pCurCtx->lineNo );
-                *pRetVal = FINISH;
-                return pzScan;
-            }
+            if (pz == (unsigned char*)pzScan)
+                AG_ABEND( asprintf( "%s Error: Invalid input char '%c' "
+                                    "in %s on line %d\n", pzProg, *pzScan,
+                                    pCurCtx->pzFileName, pCurCtx->lineNo ));
+
             *pRetVal = TK_VAR_NAME;
         } else {
             *pRetVal = TK_OTHER_NAME;
@@ -599,11 +581,11 @@ assembleName( char* pzScan, YYSTYPE* pRetVal )
  *  A quoted string has been found.
  *  Find the end of it and compress any escape sequences.
  */
-    STATIC char*
+STATIC char*
 assembleHereString( char* pzScan )
 {
     ag_bool  trimTabs = AG_FALSE;
-    char     zMark[ 64 ];
+    char     zMark[ MAX_HEREMARK_LEN ];
     int      markLen = 0;
     char*    pzDest;
 
@@ -619,11 +601,9 @@ assembleHereString( char* pzScan )
      *  Skip white space up to the marker or EOL
      */
     while (isspace( *pzScan )) {
-        if (*pzScan++ == '\n') {
-            fprintf( stderr, zErrMsg, pzProg, "HereString missing the mark",
-                     pCurCtx->pzFileName, pCurCtx->lineNo );
-            return (char*)NULL;
-        }
+        if (*pzScan++ == '\n')
+            AG_ABEND( asprintf( zErrMsg, pzProg, "HereString missing the mark",
+                                pCurCtx->pzFileName, pCurCtx->lineNo ));
     }
 
     /*
@@ -632,20 +612,16 @@ assembleHereString( char* pzScan )
     {
         char* pz = zMark;
         while (ISNAMECHAR( *pzScan )) {
-            if (++markLen >= sizeof(zMark)) {
-                fprintf( stderr, zErrMsg, pzProg,
-                         "HereString mark over 63 chars",
-                         pCurCtx->pzFileName, pCurCtx->lineNo );
-                return (char*)NULL;
-            }
+            if (++markLen >= sizeof(zMark))
+                AG_ABEND( asprintf( zErrMsg, pzProg, "HereString mark "
+                                    STR( MAX_HEREMARK_LEN ) " or more chars",
+                                    pCurCtx->pzFileName, pCurCtx->lineNo ));
 
             *(pz++) = *(pzScan++);
         }
-        if (markLen == 0) {
-            fprintf( stderr, zErrMsg, pzProg, "HereString missing the mark",
-                     pCurCtx->pzFileName, pCurCtx->lineNo );
-            return (char*)NULL;
-        }
+        if (markLen == 0)
+            AG_ABEND( asprintf( zErrMsg, pzProg, "HereString missing the mark",
+                                pCurCtx->pzFileName, pCurCtx->lineNo ));
         *pz = NUL;
     }
 
@@ -656,11 +632,9 @@ assembleHereString( char* pzScan )
      *  Skip forward to the EOL after the marker.
      */
     pzScan = strchr( pzScan, '\n' );
-    if (pzScan == (char*)NULL) {
-        fprintf( stderr, zErrMsg, pzProg, "Unterminated HereString",
-                 pCurCtx->pzFileName, pCurCtx->lineNo );
-        return (char*)NULL;
-    }
+    if (pzScan == NULL)
+        AG_ABEND( asprintf( zErrMsg, pzProg, "Unterminated HereString",
+                            pCurCtx->pzFileName, pCurCtx->lineNo ));
 
     /*
      *  And skip the first new line + conditionally skip tabs
@@ -684,9 +658,8 @@ assembleHereString( char* pzScan )
                 goto lineDone;
 
             case NUL:
-                fprintf( stderr, zErrMsg, pzProg, "Unterminated HereString",
-                         pCurCtx->pzFileName, pCurCtx->lineNo );
-                return (char*)NULL;
+                AG_ABEND( asprintf( zErrMsg, pzProg, "Unterminated HereString",
+                                    pCurCtx->pzFileName, pCurCtx->lineNo ));
             }
         } lineDone:;
 
@@ -710,7 +683,7 @@ assembleHereString( char* pzScan )
  *  A quoted string has been found.
  *  Find the end of it and compress any escape sequences.
  */
-    STATIC char*
+STATIC char*
 assembleString( char* pzScan )
 {
     char  q = *(pzScan++);
@@ -765,7 +738,7 @@ assembleString( char* pzScan )
 
         switch (*(pzD++) = *(pzS++)) {
         case NUL:
-            return (char*)NULL;
+            return NULL;
 
         case '\n':
             pCurCtx->lineNo++;
@@ -790,7 +763,7 @@ assembleString( char* pzScan )
             else if (q != '\'') {
                 int ct = doEscapeChar( pzS, pzD-1 );
                 if (ct == 0)
-                    return (char*)NULL;
+                    return NULL;
 
                 pzS += ct;
             }     /* if (q != '\'')                  */
