@@ -1,12 +1,12 @@
 /*
- *  $Id: defLoad.c,v 1.14 2001/04/30 03:38:32 bkorb Exp $
+ *  $Id: defLoad.c,v 3.8 2002/01/29 03:05:55 bkorb Exp $
  *  This module loads the definitions, calls yyparse to decipher them,
  *  and then makes a fixup pass to point all children definitions to
  *  their parent definition.
  */
 
 /*
- *  AutoGen copyright 1992-1999 Bruce Korb
+ *  AutoGen copyright 1992-2002 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -30,21 +30,20 @@ STATIC int compareIndex( const void* p1, const void* p2 );
 STATIC void fixTwins( tDefEntry** ppNode );
 STATIC void massageDefTree( tDefEntry** ppNode );
 
-#if defined( DEBUG ) && defined( VALUE_OPT_SHOW_DEFS )
+#if defined( DEBUG )
 static char zFmt[ 64 ];
 #endif
 
-    STATIC int
+STATIC int
 compareIndex( const void* p1, const void* p2 )
 {
     tDefEntry* pE1 = *((tDefEntry**)p1);
     tDefEntry* pE2 = *((tDefEntry**)p2);
     int  res = pE1->index - pE2->index;
-    if (res == 0) {
-        fprintf( stderr, "ERROR: two %s entries have index %ld\n",
-                 pE1->pzDefName, pE1->index );
-        AG_ABEND;
-    }
+    if (res == 0)
+        AG_ABEND( asprintf( "two %s definitions have index %ld\n",
+                            pE1->pzDefName, pE1->index ));
+
     return res;
 }
 
@@ -57,7 +56,7 @@ compareIndex( const void* p1, const void* p2 )
  *  Once they are all sorted, then we link them together
  *  in that order.
  */
-    STATIC void
+STATIC void
 fixTwins( tDefEntry** ppNode )
 {
     long curMax = -1;
@@ -68,7 +67,7 @@ fixTwins( tDefEntry** ppNode )
     tDefEntry* pNxt = pTw->pNext;
     void*  ap[ 16 ];
 
-    pTw->pNext = (tDefEntry*)NULL;
+    pTw->pNext = NULL;
 
     /*
      *  Do the initial twin scan, assigning index numbers as needed
@@ -82,7 +81,7 @@ fixTwins( tDefEntry** ppNode )
 
         twinCt++;
         pTw = pTw->pTwin;
-    } while (pTw != (tDefEntry*)NULL);
+    } while (pTw != NULL);
 
     /*
      *  Try to avoid allocating a pointer array,
@@ -99,7 +98,7 @@ fixTwins( tDefEntry** ppNode )
      *  Reinsert the "next" pointer into the new first entry
      */
     for (pTw = *ppNode, idx = 0;
-         pTw != (tDefEntry*)NULL;
+         pTw != NULL;
          idx++, pTw = pTw->pTwin) {
         p[idx] = (void*)pTw;
     }
@@ -115,7 +114,7 @@ fixTwins( tDefEntry** ppNode )
         *ppNode = (tDefEntry*)p[idx];
         ppNode = &((tDefEntry*)(p[idx]))->pTwin;
     }
-    *ppNode = (tDefEntry*)NULL;
+    *ppNode = NULL;
 
     /*
      *  If we allocated the pointer array, dump it now
@@ -135,19 +134,19 @@ fixTwins( tDefEntry** ppNode )
  *  but different indexes).  This routine does that.
  *  It is recursive, handling one level at a time.
  */
-    STATIC void
+STATIC void
 massageDefTree( tDefEntry** ppNode )
 {
     static int lvl = 0;
     tDefEntry*  pNode;
 
-#if defined( DEBUG ) && defined( VALUE_OPT_SHOW_DEFS )
+#if defined( DEBUG )
     if (HAVE_OPT( SHOW_DEFS ))
         snprintf( zFmt, 64, "%%%dd %%-%ds = ", 3 + (lvl * 2), 20 - (lvl * 2) );
 #endif
 
     do  {
-        tDefEntry** ppNextSib  = (tDefEntry**)NULL;
+        tDefEntry** ppNextSib  = NULL;
 
         pNode = *ppNode;
 
@@ -155,7 +154,7 @@ massageDefTree( tDefEntry** ppNode )
          *  IF this node has a twin (definition with same name)
          *  THEN ...
          */
-        if (pNode->pTwin != (tDefEntry*)NULL) {
+        if (pNode->pTwin != NULL) {
             fixTwins( ppNode );
             pNode = *ppNode;  /* new first entry */
 
@@ -171,7 +170,7 @@ massageDefTree( tDefEntry** ppNode )
                     pNextTwin->pPrevTwin = pPrevTwin;
                     pPrevTwin = pNextTwin;
                     pNextTwin = pNextTwin->pTwin;
-                } while (pNextTwin != (tDefEntry*)NULL);
+                } while (pNextTwin != NULL);
 
                 /*
                  *  The eldest twin has a baby twin pointer
@@ -189,15 +188,15 @@ massageDefTree( tDefEntry** ppNode )
         ppNode = &(pNode->pNext);
 
     skipTwinFix:
-#if defined( DEBUG ) && defined( VALUE_OPT_SHOW_DEFS )
+#if defined( DEBUG )
         if (HAVE_OPT(SHOW_DEFS))
-            printf( zFmt, pNode->index, pNode->pzDefName );
+            fprintf( pfTrace, zFmt, pNode->index, pNode->pzDefName );
 #endif
 
         if (pNode->valType == VALTYP_BLOCK) {
-#if defined( DEBUG ) && defined( VALUE_OPT_SHOW_DEFS )
+#if defined( DEBUG )
             if (HAVE_OPT(SHOW_DEFS))
-                fputs( "{...}\n", stdout );
+                fputs( "{...}\n", pfTrace );
 #endif
             /*
              *  Do this same function on all the children of this
@@ -208,7 +207,7 @@ massageDefTree( tDefEntry** ppNode )
             lvl--;
         }
 
-#if defined( DEBUG ) && defined( VALUE_OPT_SHOW_DEFS )
+#if defined( DEBUG )
         /*
          *  IF we are displaying definitions,
          *  THEN show what we can on a single line for this text definition
@@ -220,14 +219,14 @@ massageDefTree( tDefEntry** ppNode )
             for (;;) {
                 char ch = *(pz++);
                 if (ch == NUL) {
-                    fputc( '\n', stdout );
+                    fputc( '\n', pfTrace );
                     break;
                 }
-                fputc( ch, stdout );
+                fputc( ch, pfTrace );
                 if (ch == '\n')
                     break;
                 if (--ct == 0) {
-                    fputc( '\n', stdout );
+                    fputc( '\n', pfTrace );
                     break;
                 }
             }
@@ -238,13 +237,13 @@ massageDefTree( tDefEntry** ppNode )
          *  IF we have to deal with a twin,
          *  THEN remember who the next sibling is and handle the twin
          */
-        if (pNode->pTwin != (tDefEntry*)NULL) {
+        if (pNode->pTwin != NULL) {
             /*
              *  IF we do not already have a next sibling pointer,
              *  THEN save it now.  We will clear this pointer when
              *       we run out of twins.
              */
-            if (ppNextSib == (tDefEntry**)NULL)
+            if (ppNextSib == NULL)
                 ppNextSib = ppNode;
 
             pNode = pNode->pTwin;
@@ -255,10 +254,29 @@ massageDefTree( tDefEntry** ppNode )
          *  IF we stashed a next sibling pointer in order to handle
          *  twins, THEN resume the scan from that point
          */
-        if (ppNextSib != (tDefEntry**)NULL)
+        if (ppNextSib != NULL)
             ppNode = ppNextSib;
 
-    } while (*ppNode != (tDefEntry*)NULL);
+    } while (*ppNode != NULL);
+}
+
+
+STATIC void
+parseDefinitions( void )
+{
+#if defined( DEBUG )
+    if (HAVE_OPT( SHOW_DEFS )) {
+        fprintf( pfTrace, "%d bytes of definition\n\n",
+                 strlen( pBaseCtx->pzData ));
+        fputs( pBaseCtx->pzData, pfTrace );
+    }
+#endif
+    pCurCtx = pBaseCtx;
+    {
+        extern int yyparse( void );
+        (void)yyparse();
+    }
+    massageDefTree( &(rootDefCtx.pDefs) );
 }
 
 
@@ -267,7 +285,7 @@ massageDefTree( tDefEntry** ppNode )
  *
  *  Suck in the entire definitions file and parse it.
  */
-    EXPORT void
+EXPORT void
 readDefines( void )
 {
     char*    pzData;
@@ -292,7 +310,13 @@ readDefines( void )
      */
     if (strcmp( OPT_ARG( DEFINITIONS ), "-" ) == 0) {
         OPT_ARG( DEFINITIONS )  = "stdin";
-        outTime  = time( (time_t*)NULL );
+        if (getenv( "REQUEST_METHOD" ) != NULL) {
+            loadCgi();
+            parseDefinitions();
+            return;
+        }
+
+        outTime  = time( NULL );
         dataSize = 0x4000 - (4+sizeof( *pBaseCtx ));
         useStdin = AG_TRUE;
     }
@@ -302,17 +326,16 @@ readDefines( void )
      *  find out how big it was and when it was last modified.
      */
     else {
+        char* pz;
         struct stat stbf;
-        if (stat( OPT_ARG( DEFINITIONS ), &stbf ) != 0) {
-            fprintf( stderr, "%s ERROR %d (%s) stat-ing %s\n",
-                     pzProg, errno, strerror( errno ),
-                     OPT_ARG( DEFINITIONS ) );
-            AG_ABEND;
-        }
+        if (stat( OPT_ARG( DEFINITIONS ), &stbf ) != 0)
+            AG_ABEND( asprintf( zCannot, errno, "stat",
+                                OPT_ARG( DEFINITIONS ), strerror( errno )));
+
         if (! S_ISREG( stbf.st_mode )) {
-            fprintf( stderr, "%s ERROR:  %s is not a regular file\n",
-                     pzProg, OPT_ARG( DEFINITIONS ) );
-            AG_ABEND;
+            errno = EINVAL;
+            AG_ABEND( asprintf( zCannot, errno, "open non-regular file",
+                                OPT_ARG( DEFINITIONS ), strerror( errno )));
         }
 
         /*
@@ -325,7 +348,7 @@ readDefines( void )
 
         if (ENABLED_OPT( SOURCE_TIME ))
              outTime = stbf.st_mtime + 1;
-        else outTime = time( (time_t*)NULL );
+        else outTime = time( NULL );
 
         useStdin = AG_FALSE;
     }
@@ -348,19 +371,16 @@ readDefines( void )
     pzData =
         pBaseCtx->pzScan =
         pBaseCtx->pzData = (char*)(pBaseCtx+1);
-    pBaseCtx->pCtx = (tScanCtx*)NULL;
+    pBaseCtx->pCtx = NULL;
 
     /*
      *  Set the input file pointer, as needed
      */
     fp = useStdin ? stdin
                   : fopen( OPT_ARG( DEFINITIONS ), "r" FOPEN_TEXT_FLAG );
-    if (fp == (FILE*)NULL) {
-        fprintf( stderr, "%s ERROR %d (%s):  cannot open %s\n",
-                 pzProg, errno, strerror( errno ),
-                 OPT_ARG( DEFINITIONS ) );
-        AG_ABEND;
-    }
+    if (fp == NULL)
+        AG_ABEND( asprintf( zCannot, errno, "open",
+                            OPT_ARG( DEFINITIONS ), strerror( errno )));
 
     /*
      *  Read until done...
@@ -379,10 +399,8 @@ readDefines( void )
             if (feof( fp ) || useStdin)
                 break;
 
-            fprintf( stderr, "%s ERROR %d (%s):  cannot read %d bytes "
-                     "from %s\n", pzProg, errno,
-                     strerror( errno ), dataSize, OPT_ARG( DEFINITIONS ) );
-            AG_ABEND;
+            AG_ABEND( asprintf( zCannot, errno, "read",
+                                OPT_ARG( DEFINITIONS ), strerror( errno )));
         }
 
         /*
@@ -426,10 +444,8 @@ readDefines( void )
         }
     }
 
-    if (pzData == pBaseCtx->pzData) {
-        fprintf( stderr, "No definition data were read.\n" );
-        AG_ABEND;
-    }
+    if (pzData == pBaseCtx->pzData)
+        AG_ABEND( "No definition data were read" );
 
     *pzData = NUL;
     AGDUPSTR( pBaseCtx->pzFileName, OPT_ARG( DEFINITIONS ), "def file name" );
@@ -440,18 +456,7 @@ readDefines( void )
      */
     if (fp != stdin)
         fclose( fp );
-#if defined( VALUE_OPT_SHOW_DEFS )
-    if (HAVE_OPT( SHOW_DEFS )) {
-        printf( "%d bytes of definition\n\n", strlen( pBaseCtx->pzData ));
-        fputs( pBaseCtx->pzData, stdout );
-    }
-#endif
-    pCurCtx = pBaseCtx;
-    {
-        extern int yyparse( void );
-        (void)yyparse();
-    }
-    massageDefTree( &(rootDefCtx.pDefs) );
+    parseDefinitions();
 }
 /*
  * Local Variables:
