@@ -11,12 +11,12 @@ static char yyrcsid[] = "$Id: skeleton.c,v 1.4 1993/12/21 18:45:32 jtc Exp $";
 #define YYPREFIX "yy"
 #line 2 "defParse.y"
 /*
- *  $Id: defParse.y,v 1.9 2001/07/15 17:20:00 bkorb Exp $
+ *  $Id: defParse.y,v 3.2 2002/01/29 03:27:48 bkorb Exp $
  *  Parse rules for the macro definitions
  */
 
 /*
- *  AutoGen copyright 1992-1999 Bruce Korb
+ *  AutoGen copyright 1992-2001 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -408,15 +408,15 @@ case 18:
 break;
 case 19:
 #line 101 "defParse.y"
-{ yyval = findPlace( yyvsp[0], (YYSTYPE)NULL ); }
+{ yyval = findPlace( (YYSTYPE)yyvsp[0], (YYSTYPE)NULL ); }
 break;
 case 20:
 #line 104 "defParse.y"
-{ yyval = findPlace( yyvsp[-3], yyvsp[-1] ); }
+{ yyval = findPlace( (YYSTYPE)yyvsp[-3], (YYSTYPE)yyvsp[-1] ); }
 break;
 case 21:
 #line 107 "defParse.y"
-{ yyval = findPlace( yyvsp[-3], yyvsp[-1] ); }
+{ yyval = findPlace( (YYSTYPE)yyvsp[-3], (YYSTYPE)yyvsp[-1] ); }
 break;
 #line 422 "y.tab.c"
     }
