@@ -1,12 +1,12 @@
 /*  -*- Mode: C -*-
  *
  *  expExtract.c
- *  $Id: expExtract.c,v 1.17 2001/11/29 06:16:15 bkorb Exp $
+ *  $Id: expExtract.c,v 3.2 2002/01/13 08:04:33 bkorb Exp $
  *  This module implements a file extraction function.
  */
 
 /*
- *  AutoGen copyright 1992-1999 Bruce Korb
+ *  AutoGen copyright 1992-2002 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -37,7 +37,7 @@
  *  if we get called again.  Likely, there will be several extractions
  *  from a single file.
  */
-    STATIC const char*
+STATIC const char*
 loadExtractData( const char* pzNewFile )
 {
     static const char* pzFile = NULL;
@@ -95,7 +95,7 @@ loadExtractData( const char* pzNewFile )
             if (sz == 0) {
                 fprintf( stderr, "Error %d (%s) reading %d bytes of %s\n",
                          errno, strerror( errno ), sbuf.st_size, pzFile );
-                LOAD_ABORT( pCurTemplate, pCurMacro, "read failure" );
+                AG_ABEND( "read failure" );
             }
 
             pzIn += sz;
@@ -123,7 +123,7 @@ loadExtractData( const char* pzNewFile )
  *  Could not find the file or could not find the markers.
  *  Either way, emit an empty enclosure.
  */
-    STATIC SCM
+STATIC SCM
 buildEmptyText( const char* pzStart, const char* pzEnd,
                 SCM def )
 {
@@ -152,7 +152,7 @@ buildEmptyText( const char* pzStart, const char* pzEnd,
 /*
  *  If we got it, emit it.
  */
-    STATIC SCM
+STATIC SCM
 extractText( const char* pzText, const char* pzStart, const char* pzEnd,
              SCM def )
 {
@@ -248,8 +248,9 @@ extractText( const char* pzText, const char* pzStart, const char* pzEnd,
  *     [ -f %1$s-fsm.c ] && mv -f %1$s-fsm.c .fsm.code" (base-name)) +]
  * @end example
  *
- * This code will move the two output files name, ".fsm.head" and ".fsm.code".
- * At the end of the 'c' output processing, I delete them.
+ * This code will move the two previously produced output files to files
+ * named ".fsm.head" and ".fsm.code".  At the end of the 'c' output
+ * processing, I delete them.
 =*/
     SCM
 ag_scm_extract( SCM file, SCM marker, SCM caveat, SCM def )
