@@ -1,11 +1,11 @@
 /*
- *  $Id: expGperf.c,v 1.12 2001/08/29 03:11:24 bkorb Exp $
+ *  $Id: expGperf.c,v 3.3 2002/01/19 07:35:23 bkorb Exp $
  *  This module implements the expression functions that should
  *  be part of Guile.
  */
 
 /*
- *  AutoGen copyright 1992-1999 Bruce Korb
+ *  AutoGen copyright 1992-2002 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -133,13 +133,8 @@ ag_scm_make_gperf( SCM name, SCM hlist )
     {
         char* pzCmd;
         pzCmd = asprintf( zMakeGperf, pzList, pzName, getpid() );
-        if (pzCmd == (char*)NULL) {
-            fprintf( stderr, "Error using %s list:  ``%s''\n\n",
-                     pzName, pzList );
-            fprintf( stderr, zMakeGperf, pzList, pzName, getpid() );
-
-            LOAD_ABORT( pCurTemplate, pCurMacro, "formatting shell command" );
-        }
+        if (pzCmd == NULL)
+            AG_ABEND( asprintf( "asprintf( %s, ...", zMakeGperf ));
 
         /*
          *  Run the command and ignore the results.
