@@ -1,12 +1,12 @@
 
 /*
- *  $Id: expGuile.c,v 1.21 2001/08/29 03:11:24 bkorb Exp $
+ *  $Id: expGuile.c,v 3.4 2002/02/02 19:22:52 bkorb Exp $
  *  This module implements the expression functions that should
  *  be part of Guile.
  */
 
 /*
- *  AutoGen copyright 1992-1999 Bruce Korb
+ *  AutoGen copyright 1992-2002 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -123,7 +123,7 @@ ag_scm_max( SCM list )
 
         case GH_TYPE_STRING:
             val = strtol( ag_scm2zchars( car, "number-in-string" ),
-                          (char**)NULL, 0 );
+                          NULL, 0 );
             break;
 
         default:
@@ -183,7 +183,7 @@ ag_scm_min( SCM list )
 
         case GH_TYPE_STRING:
             val = strtol( ag_scm2zchars( car, "number-in-string" ),
-                          (char**)NULL, 0 );
+                          NULL, 0 );
             break;
 
         default:
@@ -231,7 +231,7 @@ ag_scm_sum( SCM list )
 
         case GH_TYPE_STRING:
             sum += strtol( ag_scm2zchars( car, "number-in-string" ),
-                           (char**)NULL, 0 );
+                           NULL, 0 );
         }
     } while (--len > 0);
 
@@ -317,7 +317,7 @@ ag_scm_string_upcase_x( SCM str )
 
 /*=gfunc string_upcase
  *
- * what:   make a new string be upper case
+ * what:   upper case a new string
  * general_use:
  *
  * exparg: str , input string
@@ -385,7 +385,7 @@ ag_scm_string_capitalize_x( SCM str )
 
 /*=gfunc string_capitalize
  *
- * what:   make a new string be capitalized
+ * what:   capitalize a new string
  * general_use:
  *
  * exparg: str , input string
@@ -445,7 +445,7 @@ ag_scm_string_downcase_x( SCM str )
 
 /*=gfunc string_downcase
  *
- * what:   make a new string be lower case
+ * what:   lower case a new string
  * general_use:
  *
  * exparg: str , input string
