@@ -1,12 +1,12 @@
 
 /*
- *  $Id: expOutput.c,v 1.19 2001/09/03 09:41:25 bkorb Exp $
+ *  $Id: expOutput.c,v 3.5 2002/01/29 03:05:55 bkorb Exp $
  *
  *  This module implements the output file manipulation function
  */
 
 /*
- *  AutoGen copyright 1992-1999 Bruce Korb
+ *  AutoGen copyright 1992-2002 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -52,7 +52,7 @@ STATIC void addWriteAccess( char* pzFileName );
 
 
 
-    EXPORT void
+EXPORT void
 removeWriteAccess( int fd )
 {
     struct stat    sbuf;
@@ -82,7 +82,7 @@ removeWriteAccess( int fd )
     fchmod( fd, sbuf.st_mode & S_IAMB );
 }
 
-    STATIC void
+STATIC void
 addWriteAccess( char* pzFileName )
 {
     struct stat    sbuf;
@@ -112,7 +112,7 @@ ag_scm_out_delete( void )
     /*
      *  Delete the current output file
      */
-    fprintf( stderr, zSkipMsg, pCurFp->pzOutName );
+    fprintf( pfTrace, zSkipMsg, pCurFp->pzOutName );
     outputDepth = 1;
     longjmp( fileAbort, PROBLEM );
     /* NOTREACHED */
@@ -163,11 +163,8 @@ ag_scm_out_pop( SCM ret_contents )
 {
     SCM res = SCM_UNDEFINED;
 
-    if (pCurFp->pPrev == (tFpStack*)NULL) {
-        fputs( "ERROR:  Cannot pop output with no output pushed\n",
-               stderr );
-        LOAD_ABORT( pCurTemplate, pCurMacro, "expr failed" );
-    }
+    if (pCurFp->pPrev == NULL)
+        AG_ABEND( "ERROR:  Cannot pop output with no output pushed\n" );
 
 
     if (gh_boolean_p( ret_contents ) && SCM_NFALSEP( ret_contents )) {
@@ -175,11 +172,9 @@ ag_scm_out_pop( SCM ret_contents )
         pos = ftell( pCurFp->pFile );
         res = scm_makstr( pos, 0 );
         rewind( pCurFp->pFile );
-        if (fread( SCM_CHARS( res ), pos, 1, pCurFp->pFile ) != 1) {
-            fprintf( stderr, "Error %d (%s) rereading output\n", errno,
-                     strerror( errno ));
-            res = SCM_UNDEFINED;
-        }
+        if (fread( SCM_CHARS( res ), pos, 1, pCurFp->pFile ) != 1)
+            AG_ABEND( asprintf( "Error %d (%s) rereading output\n",
+                                errno, strerror( errno )));
     }
 
     outputDepth--;
@@ -206,11 +201,8 @@ ag_scm_out_suspend( SCM suspName )
     SCM res = SCM_UNDEFINED;
     tCC* pzSuspName = ag_scm2zchars( suspName, "suspend name" );
 
-    if (pCurFp->pPrev == (tFpStack*)NULL) {
-        fputs( "ERROR:  Cannot pop output with no output pushed\n",
-               stderr );
-        LOAD_ABORT( pCurTemplate, pCurMacro, "expr failed" );
-    }
+    if (pCurFp->pPrev == NULL)
+        AG_ABEND( "ERROR:  Cannot pop output with no output pushed" );
 
     if (++suspendCt > suspAllocCt) {
         suspAllocCt += 8;
@@ -261,9 +253,8 @@ ag_scm_out_resume( SCM suspName )
         }
     }
 
-    fprintf( stderr, "ERROR: no output file was suspended as ``%s''\n",
-             pzName );
-    LOAD_ABORT( pCurTemplate, pCurMacro, "resume failed" );
+    AG_ABEND( asprintf( "ERROR: no output file was suspended as ``%s''\n",
+                        pzName ));
     return SCM_UNDEFINED;
 }
 
@@ -286,17 +277,23 @@ ag_scm_out_push_add( SCM new_file )
     if (! gh_string_p( new_file ))
         return SCM_UNDEFINED;
 
-    p = (tFpStack*)AGALOC( sizeof( tFpStack ), "append - out file stack" );
-    p->pPrev     = pCurFp;
-    p->flags     = FPF_FREE;
-
     pzNewFile    = gh_scm2newstr( new_file, NULL );
     addWriteAccess( pzNewFile );
-    p->pFile     = fopen( pzNewFile, "a" FOPEN_BINARY_FLAG "+" );
+    {
+        FILE* fp = fopen( pzNewFile, "a" FOPEN_BINARY_FLAG "+" );
 
+        if (fp == NULL)
+            AG_ABEND( asprintf( zCannot, errno, "open for write", pzNewFile,
+                                strerror( errno )));
+        p = (tFpStack*)AGALOC( sizeof( tFpStack ), "append - out file stack" );
+        p->pFile = fp;
+    }
+
+    p->pPrev     = pCurFp;
+    p->flags     = FPF_FREE;
     p->pzOutName = pzNewFile;
     outputDepth++;
-    pCurFp    = p;
+    pCurFp       = p;
     return SCM_UNDEFINED;
 }
 
@@ -328,13 +325,38 @@ ag_scm_out_push_new( SCM new_file )
         pzNewFile = gh_scm2newstr( new_file, NULL );
         unlink( pzNewFile );
         addWriteAccess( pzNewFile );
-        p->pFile  = fopen( pzNewFile, "a" FOPEN_BINARY_FLAG "+" );
+        p->pFile = fopen( pzNewFile, "a" FOPEN_BINARY_FLAG "+" );
     } else {
-        AGDUPSTR( pzNewFile, ".agtmp.XXXXXX", "temp file name" );
+        tSCC* pzTemp = NULL;
+        int tmpfd;
+
+        if (pzTemp == NULL) {
+            char* pz = getenv( "TEMP" );
+            if (pz == NULL) {
+                pz = getenv( "TMP" );
+                if (pz == NULL)
+                    pz = "/tmp";
+            }
+
+            pzTemp = asprintf( "%s/agtmp.XXXXXX", pz );
+            if (pzTemp == NULL)
+                AG_ABEND( "cannot allocate temp file template" );
+        }
+
+        AGDUPSTR( pzNewFile, pzTemp, "temp file name" );
         p->flags |= FPF_UNLINK;
-        p->pFile  = fdopen( mkstemp( pzNewFile ), "a" FOPEN_BINARY_FLAG "+" );
+        tmpfd = mkstemp( pzNewFile );
+        if (tmpfd < 0)
+            AG_ABEND( asprintf( "failed to create temp file from `%s'",
+                                pzTemp ));
+
+        p->pFile  = fdopen( tmpfd, "a" FOPEN_BINARY_FLAG "+" );
     }
 
+    if (p->pFile == NULL)
+        AG_ABEND( asprintf( zCannot, errno, "open for write", pzNewFile,
+                            strerror( errno )));
+
     p->pzOutName = pzNewFile;
     outputDepth++;
     pCurFp    = p;
@@ -381,17 +403,15 @@ ag_scm_out_switch( SCM new_file )
      */
     unlink( pzNewFile );
     if (   freopen( pzNewFile, "w" FOPEN_BINARY_FLAG, pCurFp->pFile )
-        != pCurFp->pFile) {
-        tSCC zOpen[] = "%s ERROR %d (%s): cannot open %s\n";
-        fprintf( stderr, zOpen, pzProg,
-                 errno, strerror( errno ), pzNewFile );
-        LOAD_ABORT( pCurTemplate, pCurMacro, "expr failed" );
-    }
+        != pCurFp->pFile)
+
+        AG_ABEND( asprintf( zCannot, errno, "freopen", pzNewFile,
+                            strerror( errno )));
 
     /*
      *  Set the mod time on the old file.
      */
-    tbuf.actime  = time( (time_t*)NULL );
+    tbuf.actime  = time( NULL );
     tbuf.modtime = outTime;
     utime( pCurFp->pzOutName, &tbuf );
     pCurFp->pzOutName = pzNewFile;  /* memory leak */
