@@ -1,6 +1,6 @@
 
 /*
- *  $Id: expPrint.c,v 1.20 2001/08/29 03:11:24 bkorb Exp $
+ *  $Id: expPrint.c,v 3.6 2002/01/19 07:35:23 bkorb Exp $
  *
  *  The following code is necessary because the user can give us
  *  a printf format requiring a string pointer yet fail to provide
@@ -10,7 +10,7 @@
  */
 
 /*
- *  AutoGen copyright 1992-1999 Bruce Korb
+ *  AutoGen copyright 1992-2002 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -45,14 +45,14 @@ STATIC size_t safePrintf( char* pzBuf, size_t bufSize,
                           char* pzFmt, void** argV );
 tSCC pzFormatName[] = "format";
 
-    STATIC void
+STATIC void
 printFault( int sig )
 {
     siglongjmp( printJumpEnv, sig );
 }
 
 
-    STATIC size_t
+STATIC size_t
 safePrintf( char* pzBuf, size_t bufSize, char* pzFmt, void** argV )
 {
     tSCC zBadArgs[]  = "Bad args to sprintf";
@@ -86,27 +86,25 @@ safePrintf( char* pzBuf, size_t bufSize, char* pzFmt, void** argV )
          *  THEN perform that fprintf
          */
         if (sigsetjmp( printJumpEnv, 0 ) == 0)
-            fprintf( stderr, zBadFmt, pzProg, strsignal( faultType ), pzFmt );
+            fprintf( pfTrace, zBadFmt, pzProg, strsignal( faultType ), pzFmt );
 
         /*
          *  The "sprintfv" command below faulted, so we exit
          */
-        LOAD_ABORT( pCurTemplate, pCurMacro, zBadArgs );
+        AG_ABEND( zBadArgs );
     }
 
     printSize = snprintfv( pzBuf, bufSize, pzFmt, (void*)argV );
-    if ((printSize & 0xF0000000) != 0) {
-        fprintf( stderr, "snprintf returned 0x%08X\n", printSize );
-        LOAD_ABORT( pCurTemplate, pCurMacro, zBadArgs );
-    }
+    if ((printSize & 0xF0000000) != 0)
+        AG_ABEND( asprintf( "snprintf returned 0x%08X\n", printSize ));
 
-    sigaction( SIGBUS,  &saSave1, (struct sigaction*)NULL );
-    sigaction( SIGSEGV, &saSave2, (struct sigaction*)NULL );
+    sigaction( SIGBUS,  &saSave1, NULL );
+    sigaction( SIGSEGV, &saSave2, NULL );
     return printSize;
 }
 
 
-    EXPORT SCM
+EXPORT SCM
 run_printf( char* pzFmt, int len, SCM alist )
 {
     SCM     res;
@@ -122,7 +120,7 @@ run_printf( char* pzFmt, int len, SCM alist )
      *  Allocate everything we need at once.  Round up to next 4096 bytes.
      *  Most likely, we allocate and free a page every time.
      */
-    bfSize += 2 * len * sizeof( void* ) + 0x0FFF;
+    bfSize += 2 * len * sizeof( void* ) + 0x100F;
     bfSize &= ~0x0FFF;
 
     arglist  = argp  = (void**)AGALOC( bfSize, "sprintf buffer" );
@@ -130,7 +128,7 @@ run_printf( char* pzFmt, int len, SCM alist )
     pzBuf    = (char*)(freelist + len);
     bfSize  -= 2 * len * sizeof( void* );
 
-    do  {
+    while (len-- > 0) {
         SCM  car = SCM_CAR( alist );
         alist = SCM_CDR( alist );
         switch (gh_type_e( car )) {
@@ -169,7 +167,7 @@ run_printf( char* pzFmt, int len, SCM alist )
             *(argp++) = (void*)"...";
             break;
         }
-    } while (--len > 0);
+    }
 
     /*
      *  Do the formatting and allocate a new SCM to hold the result.
@@ -257,5 +255,6 @@ ag_scm_fprintf( SCM port, SCM fmt, SCM alist )
 /*
  * Local Variables:
  * c-file-style: "stroustrup"
+ * indent-tabs-mode: nil
  * End:
  * end of expPrint.c */
