@@ -1,12 +1,12 @@
 
 /*
- *  $Id: funcCase.c,v 1.35 2001/11/03 22:46:44 bkorb Exp $
+ *  $Id: funcCase.c,v 3.4 2002/01/19 07:35:24 bkorb Exp $
  *
  *  This module implements the CASE text function.
  */
-
+/*=--subblock=exparg=arg_name,arg_desc,arg_optional,arg_list=*/
 /*
- *  AutoGen copyright 1992-2001 Bruce Korb
+ *  AutoGen copyright 1992-2002 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -74,7 +74,7 @@ STATIC tSelectProc
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-    STATIC void
+STATIC void
 compile_re( regex_t* pRe, char* pzPat, int flags )
 {
     int  rerr = regcomp( pRe, pzPat, flags );
@@ -82,12 +82,12 @@ compile_re( regex_t* pRe, char* pzPat, int flags )
         char zEr[ 128 ];
         regerror( rerr, pRe, zEr, sizeof( zEr ));
         fprintf( stderr, zBadRe, rerr, zEr, pzPat );
-        LOAD_ABORT( pCurTemplate, pCurMacro, "Bad regular expression" );
+        AG_ABEND( "Bad regular expression" );
     }
 }
 
 
-    STATIC void
+STATIC void
 upString( char* pz )
 {
     while (*pz != NUL)
@@ -109,7 +109,7 @@ upString( char* pz )
  * doc:  Test to see if a string contains a substring.  "strstr(3)"
  *       will find an address.
 =*/
-    STATIC tSuccess
+STATIC tSuccess
 Select_Compare( char* pzText, char* pzMatch )
 {
     return (strstr( pzText, pzMatch )) ? SUCCESS : FAILURE;
@@ -122,7 +122,7 @@ ag_scm_string_contains_p( SCM text, SCM substr )
     char* pzSubstr = ag_scm2zchars( substr, "match expr" );
     SCM   res;
 
-    res = (strstr( pzText, pzSubstr) == (char*)NULL) ? SCM_BOOL_F : SCM_BOOL_T;
+    res = (strstr( pzText, pzSubstr) == NULL) ? SCM_BOOL_F : SCM_BOOL_T;
 
     if (OPT_VALUE_TRACE > TRACE_EXPRESSIONS)
         fprintf( pfTrace, zTrFmt, (res == SCM_BOOL_T) ? zTrue : zFalse,
@@ -144,7 +144,7 @@ ag_scm_string_contains_p( SCM text, SCM substr )
  * doc:  Test to see if a string ends with a substring.
  *       strcmp(3) returns zero for comparing the string ends.
 =*/
-    STATIC tSuccess
+STATIC tSuccess
 Select_Compare_End( char* pzText, char* pzMatch )
 {
     size_t   vlen = strlen( pzMatch );
@@ -186,7 +186,7 @@ ag_scm_string_ends_with_p( SCM text, SCM substr )
  *
  * doc:  Test to see if a string starts with a substring.
 =*/
-    STATIC tSuccess
+STATIC tSuccess
 Select_Compare_Start( char* pzText, char* pzMatch )
 {
     size_t  vlen = strlen( pzMatch );
@@ -225,7 +225,7 @@ ag_scm_string_starts_with_p( SCM text, SCM substr )
  *
  * doc:  Test to see if two strings exactly match.
 =*/
-    STATIC tSuccess
+STATIC tSuccess
 Select_Compare_Full( char* pzText, char* pzMatch )
 {
     tSuccess res = (strcmp( pzText, pzMatch ) == 0) ? SUCCESS : FAILURE;
@@ -268,14 +268,14 @@ ag_scm_string_equals_p( SCM text, SCM substr )
  *       to character case and certain characters are considered `equivalent'.
  *       Viz., '-', '_' and '^' are equivalent.
 =*/
-    STATIC tSuccess
+STATIC tSuccess
 Select_Equivalent( char* pzText, char* pzMatch )
 {
     char*    pz  = strdup( pzText );
     tSuccess res = SUCCESS;
 
     upString( pz );
-    if (strstr( pz, pzMatch ) == (char*)NULL)
+    if (strstr( pz, pzMatch ) == NULL)
         res = FAILURE;
     AGFREE( (void*)pz );
 
@@ -317,7 +317,7 @@ ag_scm_string_contains_eqv_p( SCM text, SCM substr )
  *
  * doc:  Test to see if a string ends with an equivalent string.
 =*/
-    STATIC tSuccess
+STATIC tSuccess
 Select_Equivalent_End( char* pzText, char* pzMatch )
 {
     size_t   vlen = strlen( pzMatch );
@@ -358,7 +358,7 @@ ag_scm_string_ends_eqv_p( SCM text, SCM substr )
  *
  * doc:  Test to see if a string starts with an equivalent string.
 =*/
-    STATIC tSuccess
+STATIC tSuccess
 Select_Equivalent_Start( char* pzText, char* pzMatch )
 {
     size_t   vlen = strlen( pzMatch );
@@ -404,7 +404,7 @@ ag_scm_string_starts_eqv_p( SCM text, SCM substr )
  *       This is an overloaded operation.  If the arguments are not both
  *       strings, then the query is passed through to @code{scm_num_eq_p()}.
 =*/
-    STATIC tSuccess
+STATIC tSuccess
 Select_Equivalent_Full( char* pzText, char* pzMatch )
 {
     return (streqvcmp( pzText, pzMatch ) == 0) ? SUCCESS : FAILURE;
@@ -463,20 +463,20 @@ ag_scm_string_eqv_p( SCM text, SCM substr )
  * doc:  Test to see if a string contains a pattern.
  *       Case is not significant.
 =*/
-    STATIC tSuccess
+STATIC tSuccess
 Select_Match( char* pzText, char* pzMatch )
 {
     /*
      *  On the first call for this macro, compile the expression
      */
-    if (pCurMacro->funcPrivate == (void*)NULL) {
+    if (pCurMacro->funcPrivate == NULL) {
         regex_t*  pRe = AGALOC( sizeof( *pRe ), "select match re" );
         compile_re( pRe, pzMatch, pCurMacro->res );
         pCurMacro->funcPrivate = (void*)pRe;
     }
 
     if (regexec( (regex_t*)pCurMacro->funcPrivate, pzText, 0,
-                 (regmatch_t*)NULL, 0 ) != 0)
+                 NULL, 0 ) != 0)
         return FAILURE;
     return SUCCESS;
 }
@@ -490,7 +490,7 @@ ag_scm_string_has_match_p( SCM text, SCM substr )
     compile_re( &re, ag_scm2zchars( substr, "match expr" ), REG_EXTENDED );
 
     if (regexec( &re, ag_scm2zchars( text, "text to match" ), 0,
-                 (regmatch_t*)NULL, 0 ) == 0)
+                 NULL, 0 ) == 0)
          res = SCM_BOOL_T;
     else res = SCM_BOOL_F;
     regfree( &re );
@@ -508,7 +508,7 @@ ag_scm_string_has_eqv_match_p( SCM text, SCM substr )
 
     compile_re( &re, pzSubstr, REG_EXTENDED | REG_ICASE );
 
-    if (regexec( &re, pzText, 0, (regmatch_t*)NULL, 0 ) == 0)
+    if (regexec( &re, pzText, 0, NULL, 0 ) == 0)
          res = SCM_BOOL_T;
     else res = SCM_BOOL_F;
     regfree( &re );
@@ -544,14 +544,14 @@ ag_scm_string_has_eqv_match_p( SCM text, SCM substr )
  * doc:  Test to see if a string ends with a pattern.
  *       Case is not significant.
 =*/
-    STATIC tSuccess
+STATIC tSuccess
 Select_Match_End( char* pzText, char* pzMatch )
 {
     regmatch_t m[2];
     /*
      *  On the first call for this macro, compile the expression
      */
-    if (pCurMacro->funcPrivate == (void*)NULL) {
+    if (pCurMacro->funcPrivate == NULL) {
         regex_t*  pRe = AGALOC( sizeof( *pRe ), "select match end re" );
         compile_re( pRe, pzMatch, pCurMacro->res );
         pCurMacro->funcPrivate = (void*)pRe;
@@ -636,14 +636,14 @@ ag_scm_string_end_eqv_match_p( SCM text, SCM substr )
  * doc:  Test to see if a string starts with a pattern.
  *       Case is not significant.
 =*/
-    STATIC tSuccess
+STATIC tSuccess
 Select_Match_Start( char* pzText, char* pzMatch )
 {
     regmatch_t m[2];
     /*
      *  On the first call for this macro, compile the expression
      */
-    if (pCurMacro->funcPrivate == (void*)NULL) {
+    if (pCurMacro->funcPrivate == NULL) {
         regex_t*  pRe = AGALOC( sizeof( *pRe ), "select match start re" );
         compile_re( pRe, pzMatch, pCurMacro->res );
         pCurMacro->funcPrivate = (void*)pRe;
@@ -729,7 +729,7 @@ ag_scm_string_start_eqv_match_p( SCM text, SCM substr )
  *       Case is not significant, but any character equivalences
  *       must be expressed in your regular expression.
 =*/
-    STATIC tSuccess
+STATIC tSuccess
 Select_Match_Full( char* pzText, char* pzMatch )
 {
     regmatch_t m[2];
@@ -737,7 +737,7 @@ Select_Match_Full( char* pzText, char* pzMatch )
     /*
      *  On the first call for this macro, compile the expression
      */
-    if (pCurMacro->funcPrivate == (void*)NULL) {
+    if (pCurMacro->funcPrivate == NULL) {
         regex_t*  pRe = AGALOC( sizeof( *pRe ), "select match full re" );
         compile_re( pRe, pzMatch, pCurMacro->res );
         pCurMacro->funcPrivate = pRe;
@@ -803,7 +803,7 @@ ag_scm_string_eqv_match_p( SCM text, SCM substr )
 /*
  *  We don't bother making a Guile function for this one :)
  */
-    STATIC tSuccess
+STATIC tSuccess
 Select_Match_Always( char* pzText, char* pzMatch )
 {
     return SUCCESS;
@@ -998,8 +998,8 @@ struct case_stack {
 STATIC tCaseStack  current_case;
 STATIC tLoadProc mLoad_Select;
 
-static tpLoadProc apCaseLoad[ FUNC_CT ]   = { (tpLoadProc)NULL };
-static tpLoadProc apSelectOnly[ FUNC_CT ] = { (tpLoadProc)NULL };
+static tpLoadProc apCaseLoad[ FUNC_CT ]   = { NULL };
+static tpLoadProc apSelectOnly[ FUNC_CT ] = { NULL };
 
 /*
  *  mLoad_CASE
@@ -1024,7 +1024,7 @@ mLoad_Case( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
      *  THEN woops!  what are we to case on?
      */
     if (srcLen == 0)
-        LOAD_ABORT( pT, pMac, "expressionless CASE" );
+        AG_ABEND_IN( pT, pMac, "expressionless CASE" );
 
     /*
      *  Load the expression
@@ -1035,11 +1035,9 @@ mLoad_Case( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
      *  IF this is the first time here,
      *  THEN set up the "CASE" mode callout table.
      *  It is the standard table, except entries are inserted
-     *  for functions that are enabled only while processing
-     *  a CASE macro
+     *  for SELECT and ESAC.
      */
-    if (apCaseLoad[0] == (tpLoadProc)NULL) {
-        extern tLoadProc mLoad_Bogus;
+    if (apCaseLoad[0] == NULL) {
         int i;
 
         /*
@@ -1071,9 +1069,9 @@ mLoad_Case( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     /*
      *  Continue parsing the template from this nested level
      */
-    pEsacMac = parseTemplate( pT, pMac+1, ppzScan );
-    if (*ppzScan == (char*)NULL)
-        LOAD_ABORT( pT, pMac, "ESAC not found" );
+    pEsacMac = parseTemplate( pMac+1, ppzScan );
+    if (*ppzScan == NULL)
+        AG_ABEND_IN( pT, pMac, "ESAC not found" );
 
     /*
      *  Tell the last select macro where its end is.
@@ -1118,7 +1116,7 @@ mLoad_Case( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
  *    Instead, you must use one of the 17 match operators described in
  *    the @code{CASE} macro description.
 =*/
-    tMacro*
+STATIC tMacro*
 mLoad_Select( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 {
     const char*    pzScan = *ppzScan;  /* text after macro */
@@ -1135,7 +1133,7 @@ mLoad_Select( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     papLoadProc = apCaseLoad;
     pMac->res   = 0;
     if (srcLen == 0)
-        LOAD_ABORT( pT, pMac, "Empty macro text" );
+        AG_ABEND_IN( pT, pMac, "Empty macro text" );
 
     /*
      *  IF the first character is an asterisk,
@@ -1180,7 +1178,7 @@ mLoad_Select( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
         break;
 
     default:
-        LOAD_ABORT( pT, pMac, zInvSel );
+        AG_ABEND_IN( pT, pMac, zInvSel );
     }
 
     /*
@@ -1194,12 +1192,12 @@ mLoad_Select( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     }
 
     if (! isspace( *pzSrc ))
-        LOAD_ABORT( pT, pMac, zInvSel );
+        AG_ABEND_IN( pT, pMac, zInvSel );
 
     while (isspace(*pzSrc)) pzSrc++;
     srcLen -= pzSrc - (const char*)pMac->ozText;
     if (srcLen <= 0)
-        LOAD_ABORT( pT, pMac, zInvSel );
+        AG_ABEND_IN( pT, pMac, zInvSel );
 
     /*
      *  See if we are doing case insensitive regular expressions
