@@ -1,12 +1,12 @@
 
 /*
- *  $Id: funcDef.c,v 1.46 2001/11/12 02:36:07 bkorb Exp $
+ *  $Id: funcDef.c,v 3.6 2002/01/19 07:35:24 bkorb Exp $
  *
  *  This module implements the DEFINE text function.
  */
 
 /*
- *  AutoGen copyright 1992-1999 Bruce Korb
+ *  AutoGen copyright 1992-2002 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -51,7 +51,7 @@ STATIC int   orderDefList( const void* p1, const void* p2 );
 STATIC void  prepInvokeArgs( tMacro* pMac );
 
 
-    STATIC int
+STATIC int
 orderDefList( const void* p1, const void* p2 )
 {
     tDefEntry* pDL1 = (tDefEntry*)p1;
@@ -69,7 +69,7 @@ orderDefList( const void* p1, const void* p2 )
 }
 
 
-    STATIC tDefList*
+STATIC tDefList*
 linkTwins( tDefList* pDL, tDefList* pNext, int* pCt )
 {
     tDefList* pN;
@@ -96,10 +96,10 @@ linkTwins( tDefList* pDL, tDefList* pNext, int* pCt )
     }
 
     pDL->de.pEndTwin  = &(pNext->de);
-    pNext->de.pTwin   = (tDefEntry*)NULL; /* NULL terminated list */
-    pDL->de.pPrevTwin = (tDefEntry*)NULL; /* NULL terminated list */
+    pNext->de.pTwin   = NULL; /* NULL terminated list */
+    pDL->de.pPrevTwin = NULL; /* NULL terminated list */
     *pCt = ct;
-    pDL->de.pNext = (tDefEntry*)NULL;     /* in case ct == 0      */
+    pDL->de.pNext = NULL;     /* in case ct == 0      */
     return pN; /* If ct is zero, then this is invalid */
 }
 
@@ -112,7 +112,7 @@ linkTwins( tDefList* pDL, tDefList* pNext, int* pCt )
  *  for name-value assignments that are only to live for the duration
  *  of the processing of the user defined macro.
  */
-    EXPORT void
+EXPORT void
 parseMacroArgs( tTemplate* pT, tMacro* pMac )
 {
     char*        pzScan = pT->pzTemplText + pMac->ozText;
@@ -136,7 +136,7 @@ parseMacroArgs( tTemplate* pT, tMacro* pMac )
         if (! isalpha( *pzScan )) {
             fprintf( stderr, "On macro argument # %d:\n%s\n",
                      ct, pzScan );
-            LOAD_ABORT( pT, pMac, "no macro arg name" );
+            AG_ABEND_IN( pT, pMac, "no macro arg name" );
         }
 
         while (ISNAMECHAR( *pzScan ))  pzScan++;
@@ -178,7 +178,7 @@ parseMacroArgs( tTemplate* pT, tMacro* pMac )
             pDL->de.pzValue = (char*)zNil; goto fill_in_array_done;
 
         default:
-            LOAD_ABORT( pT, pMac, "name not followed by '='" );
+            AG_ABEND_IN( pT, pMac, "name not followed by '='" );
 
         case ' ': case '\t': case '\n': case '\f':
             *(pzScan++) = NUL;
@@ -203,6 +203,7 @@ parseMacroArgs( tTemplate* pT, tMacro* pMac )
          *  Now we have gather up the assigned value.
          */
         while (isspace( *pzScan ))     pzScan++;
+        strtransform( pDL->de.pzDefName, pDL->de.pzDefName );
         pDL->pzExpr = pzScan;
         pDL->de.valType = VALTYP_TEXT;
         pzScan = (char*)skipExpression( pzScan, strlen( pzScan ));
@@ -248,7 +249,7 @@ parseMacroArgs( tTemplate* pT, tMacro* pMac )
              *  Default:  the raw sequence of characters is the value
              */
             pDL->de.pzValue = pDL->pzExpr;
-            pDL->pzExpr     = (char*)NULL;
+            pDL->pzExpr     = NULL;
         }
 
         /*
@@ -259,7 +260,7 @@ parseMacroArgs( tTemplate* pT, tMacro* pMac )
             break;
 
         if (! isspace( *pzScan ))
-            LOAD_ABORT( pT, pMac, "no space separating entries" );
+            AG_ABEND_IN( pT, pMac, "no space separating entries" );
 
         /*
          *  Terminate the string value and skip over any additional space
@@ -284,7 +285,7 @@ parseMacroArgs( tTemplate* pT, tMacro* pMac )
          */
         for (;;) {
             if (--ct == 0) {
-                pDL->de.pNext = (tDefEntry*)NULL;
+                pDL->de.pNext = NULL;
                 break;
             }
 
@@ -307,14 +308,14 @@ parseMacroArgs( tTemplate* pT, tMacro* pMac )
 }
 
 
-    STATIC void
+STATIC void
 prepInvokeArgs( tMacro* pMac )
 {
     char*  pzText;
     tTemplate* pT = pCurTemplate;
 
     if (pMac->ozText == 0)
-        LOAD_ABORT( pT, pMac, "The INVOKE macro requires a name" );
+        AG_ABEND_IN( pT, pMac, "The INVOKE macro requires a name" );
     pMac->ozName = pMac->ozText;
     pzText = pT->pzTemplText + pMac->ozText;
     pzText = (char*)skipExpression( pzText, strlen( pzText ));
@@ -334,7 +335,7 @@ prepInvokeArgs( tMacro* pMac )
      */
     else {
         if (! isspace( *pzText ))
-            LOAD_ABORT( pT, pMac,
+            AG_ABEND_IN( pT, pMac,
                         "The INVOKE macro name not space separated" );
         *pzText = NUL;
         while (isspace( *++pzText ))  ;
@@ -405,7 +406,7 @@ build_defs( int defCt, tDefList* pList )
      *      and set the text value to it.
      */
     do  {
-        if (pList->pzExpr == (char*)NULL)
+        if (pList->pzExpr == NULL)
             continue;
 
     retryExpression:
@@ -413,7 +414,7 @@ build_defs( int defCt, tDefList* pList )
         case ';':
         {
             char* pz = strchr( pList->pzExpr, '\n' );
-            if (pz != (char*)NULL) {
+            if (pz != NULL) {
                 while (isspace( *++pz ))  ;
                 pList->pzExpr = pz;
                 goto retryExpression;
@@ -421,7 +422,7 @@ build_defs( int defCt, tDefList* pList )
             /* FALLTHROUGH */
         }
         case NUL:
-            pList->pzExpr = (char*)NULL;
+            pList->pzExpr = NULL;
             pList->de.pzValue = (char*)zNil;
             break;
 
@@ -566,9 +567,9 @@ mFunc_Define( tTemplate* pT, tMacro* pMac )
     if ((defCt = pMac->sibIndex) > 0) {
         pList = (tDefList*)pMac->res;
         while (defCt-- > 0) {
-            if (pList->pzExpr != (char*)NULL) {
+            if (pList->pzExpr != NULL) {
                 AGFREE( (void*)pList->de.pzValue );
-                pList->de.pzValue = (char*)NULL;
+                pList->de.pzValue = NULL;
             }
             pList++;
         }
@@ -627,10 +628,10 @@ mFunc_Invoke( tTemplate* pT, tMacro* pMac )
             pMac->funcPrivate = (void*)findTemplate(
                 pT->pzTemplText + pMac->ozName );
 
-            if (pMac->funcPrivate == (void*)NULL) {
+            if (pMac->funcPrivate == NULL) {
                 pzText = asprintf( zNoResolution,
                                    pT->pzTemplText + pMac->ozName );
-                LOAD_ABORT( pT, pMac, pzText );
+                AG_ABEND_IN( pT, pMac, pzText );
             }
 
             return mFunc_Define( pT, pMac );
@@ -644,10 +645,10 @@ mFunc_Invoke( tTemplate* pT, tMacro* pMac )
     macName = eval( pT->pzTemplText + pMac->ozName );
 
     pInv = findTemplate( ag_scm2zchars( macName, "macro name" ));
-    if (pInv == (tTemplate*)NULL) {
+    if (pInv == NULL) {
         pzText = asprintf( zNoResolution,
                            ag_scm2zchars( macName, "macro name" ));
-        LOAD_ABORT( pT, pMac, pzText );
+        AG_ABEND_IN( pT, pMac, pzText );
     }
 
     pMac->funcPrivate = (void*)pInv;
@@ -680,10 +681,10 @@ mLoad_Define( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
      *  Save the global macro loading mode
      */
     tpLoadProc* papLP = papLoadProc;
-    static tpLoadProc apDefineLoad[ FUNC_CT ] = { (tpLoadProc)NULL };
+    static tpLoadProc apDefineLoad[ FUNC_CT ] = { NULL };
 
     if (pMac->ozText == 0)
-        LOAD_ABORT( pT, pMac, zNameNeeded );
+        AG_ABEND_IN( pT, pMac, zNameNeeded );
 
     /*
      *  IF this is the first time here,
@@ -692,7 +693,7 @@ mLoad_Define( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
      *  for functions that are enabled only while processing
      *  a DEFINE block (i.e. "ENDDEF")
      */
-    if (apDefineLoad[0] == (tpLoadProc)NULL) {
+    if (apDefineLoad[0] == NULL) {
         memcpy( (void*)apDefineLoad, apLoadProc, sizeof( apLoadProc ));
         apDefineLoad[ FTYP_ENDDEF ] = &mLoad_Ending;
     }
@@ -719,10 +720,10 @@ mLoad_Define( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
         pNewT->descSize = alocSize;
         pNewT->macroCt  = macCt;
         pNewT->pzFileName = (char*)(pNewT->aMacros + macCt);
-        memcpy( pNewT->pzFileName, pT->pzFileName, fnameSize );
-        pzCopy = pNewT->pzTplName = pNewT->pzFileName + fnameSize;
+        memcpy( (void*)pNewT->pzFileName, pT->pzFileName, fnameSize );
+        pzCopy = pNewT->pzTplName = (void*)(pNewT->pzFileName + fnameSize);
         if (! isalpha( *pzSrc ))
-            LOAD_ABORT( pT, pMac, zNameNeeded );
+            AG_ABEND_IN( pT, pMac, zNameNeeded );
 
         while (ISNAMECHAR(*pzSrc))  *(pzCopy++) = *(pzSrc++);
     }
@@ -732,15 +733,16 @@ mLoad_Define( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     pNewT->pNext = pzCopy+1;
     strcpy( pNewT->zStartMac, pT->zStartMac );
     strcpy( pNewT->zEndMac, pT->zEndMac );
+    pCurTemplate = pNewT;
 
     {
-        tMacro* pMacEnd = parseTemplate( pNewT, pNewT->aMacros, ppzScan );
+        tMacro* pMacEnd = parseTemplate( pNewT->aMacros, ppzScan );
 
         /*
          *  Make sure all of the input string was *NOT* scanned.
          */
-        if (*ppzScan == (char*)NULL)
-            LOAD_ABORT( pT, pMac, "parse ended unexpectedly" );
+        if (*ppzScan == NULL)
+            AG_ABEND_IN( pT, pMac, "parse ended unexpectedly" );
 
         pNewT->macroCt = pMacEnd - &(pNewT->aMacros[0]);
 
@@ -783,11 +785,12 @@ mLoad_Define( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
      *  the entries are all linked together and
      *  realloc-ing it may cause it to move.
      */
-#if defined( DEBUG ) && defined( VALUE_OPT_SHOW_DEFS )
+#if defined( DEBUG )
     if (HAVE_OPT( SHOW_DEFS )) {
         tSCC zSum[] = "loaded %d macros from %s\n"
             "\tBinary template size:  0x%X\n\n";
-        printf( zSum, pNewT->macroCt, pNewT->pzFileName, pNewT->descSize );
+        fprintf( pfTrace, zSum, pNewT->macroCt, pNewT->pzFileName,
+                 pNewT->descSize );
     }
 #endif
 
@@ -795,10 +798,12 @@ mLoad_Define( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     pNamedTplList = pNewT;
     papLoadProc = papLP;
     memset( (void*)pMac, 0, sizeof(*pMac) );
+    pCurTemplate = pT;
     return pMac;
 }
 /*
  * Local Variables:
  * c-file-style: "stroustrup"
+ * indent-tabs-mode: nil
  * End:
  * end of funcDef.c */
