@@ -1,12 +1,12 @@
 
 /*
- *  $Id: funcEval.c,v 1.39 2001/11/03 22:46:44 bkorb Exp $
+ *  $Id: funcEval.c,v 3.6 2002/01/19 07:35:24 bkorb Exp $
  *
  *  This module evaluates macro expressions.
  */
 
 /*
- *  AutoGen copyright 1992-2001 Bruce Korb
+ *  AutoGen copyright 1992-2002 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -41,7 +41,7 @@ tSCC        zNil[] = "";
 STATIC int exprType( char* pz );
 
 
-    EXPORT char*
+EXPORT char*
 resolveSCM( SCM s )
 {
     static char z[32];
@@ -109,7 +109,7 @@ resolveSCM( SCM s )
  *  It may need to be deallocated, so a boolean pointer is used
  *  to tell the caller.
  */
-    EXPORT char*
+EXPORT char*
 evalExpression( ag_bool* pMustFree )
 {
     tTemplate*  pT      = pCurTemplate;
@@ -132,7 +132,7 @@ evalExpression( ag_bool* pMustFree )
          */
         pDef = findDefEntry( pT->pzTemplText + pMac->ozName, &isIndexed );
 
-        if (pDef == (tDefEntry*)NULL) {
+        if (pDef == NULL) {
             switch (code & (EMIT_IF_ABSENT | EMIT_ALWAYS)) {
             case EMIT_IF_ABSENT:
                 /*
@@ -162,7 +162,7 @@ evalExpression( ag_bool* pMustFree )
                 /*
                  *  Emit inconsistently :-}
                  */
-                LOAD_ABORT( pT, pMac, "PROGRAM ERROR:  ambiguous expr code" );
+                AG_ABEND_IN( pT, pMac, "PROGRAM ERROR:  ambiguous expr code" );
             }
         }
 
@@ -177,7 +177,7 @@ evalExpression( ag_bool* pMustFree )
 
             if (  (pDef->valType != VALTYP_TEXT)
                && ((code & EMIT_PRIMARY_TYPE) == EMIT_VALUE)  ) {
-                fprintf( stderr, zTplWarn, pT->pzFileName, pMac->lineNo,
+                fprintf( pfTrace, zTplWarn, pT->pzFileName, pMac->lineNo,
                          zBlock );
                 return (char*)zNil;
             }
@@ -198,7 +198,7 @@ evalExpression( ag_bool* pMustFree )
                  *  And make sure what we found is a text value
                  */
                 if (pDef->valType != VALTYP_TEXT) {
-                    fprintf( stderr, zTplWarn, pT->pzFileName, pMac->lineNo,
+                    fprintf( pfTrace, zTplWarn, pT->pzFileName, pMac->lineNo,
                              zBlock );
                     return (char*)zNil;
                 }
@@ -216,7 +216,7 @@ evalExpression( ag_bool* pMustFree )
                  *  And make sure what we found is a text value
                  */
                 if (pDef->valType != VALTYP_TEXT) {
-                    fprintf( stderr, zTplWarn, pT->pzFileName, pMac->lineNo,
+                    fprintf( pfTrace, zTplWarn, pT->pzFileName, pMac->lineNo,
                              zBlock );
                     return (char*)zNil;
                 }
@@ -261,7 +261,7 @@ evalExpression( ag_bool* pMustFree )
         if (*pMustFree)
             AGFREE( (void*)pzText );
 
-        if (pz != (char*)NULL) {
+        if (pz != NULL) {
             *pMustFree = AG_TRUE;
             pzText = pz;
         }
@@ -283,6 +283,7 @@ evalExpression( ag_bool* pMustFree )
 /*=gfunc error_source_line
  *
  * what: display of file & line
+ * general_use:
  * doc:  This function is only invoked just before Guile displays
  *       an error message.  It displays the file name and line number
  *       that triggered the evaluation error.  You should not need to
@@ -310,7 +311,7 @@ ag_scm_error_source_line( void )
  *  digest the string and return that.  Otherwise, just return
  *  the string.
  */
-    EXPORT SCM
+EXPORT SCM
 eval( const char* pzExpr )
 {
     ag_bool allocated = AG_FALSE;
@@ -389,7 +390,7 @@ mFunc_Expr( tTemplate* pT, tMacro* pMac )
 #endif /* DEFINE_LOAD_FUNCTIONS */
 
 
-    STATIC int
+STATIC int
 exprType( char* pz )
 {
     switch (*pz) {
@@ -472,20 +473,16 @@ mLoad_Expr( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     {
         size_t remLen = canonicalizeName( pzCopy, pzSrc, srcLen );
         if (remLen > srcLen)
-            LOAD_ABORT( pT, pMac, "Invalid definition name" );
+            AG_ABEND_IN( pT, pMac, "Invalid definition name" );
         pzSrc  += srcLen - remLen;
         srcLen  = remLen;
         pzCopy += strlen( pzCopy )+1;
     }
 
     if (pzSrc >= pzSrcEnd) {
-        if (pMac->res != EMIT_VALUE) {
-            tSCC zAb[] = "No replacement text for unfound value";
-            tSCC zFm[] = "No formatting string for format expr";
-            fprintf( stderr, zTplErr, pT->pzFileName, pMac->lineNo,
-                     (pMac->res == EMIT_IF_ABSENT) ? zAb : zFm );
-            LOAD_ABORT( pT, pMac, "definition expression" );
-        }
+        if (pMac->res != EMIT_VALUE)
+            AG_ABEND_IN( pT, pMac, "No text for unfound value" );
+
         pMac->ozText = 0;
 
     } else {
@@ -510,10 +507,10 @@ mLoad_Expr( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
              *  The next expression must be within bounds and space separated
              */
             if (pzNextExpr >= pz + srcLen)
-                LOAD_ABORT( pT, pMac, "`?' needs two expressions" );
+                AG_ABEND_IN( pT, pMac, "`?' needs two expressions" );
 
             if (! isspace( *pzNextExpr ))
-                LOAD_ABORT( pT, pMac, "No space between expressions" );
+                AG_ABEND_IN( pT, pMac, "No space between expressions" );
 
             /*
              *  NUL terminate the first expression, skip intervening
@@ -535,5 +532,6 @@ mLoad_Expr( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 /*
  * Local Variables:
  * c-file-style: "stroustrup"
+ * indent-tabs-mode: nil
  * End:
  * end of funcEval.c */
