@@ -1,12 +1,12 @@
 
 /*
- *  $Id: functions.c,v 1.25 2001/11/03 22:46:44 bkorb Exp $
+ *  $Id: functions.c,v 3.4 2002/01/19 07:35:24 bkorb Exp $
  *
  *  This module implements text functions.
  */
 
 /*
- *  AutoGen copyright 1992-1999 Bruce Korb
+ *  AutoGen copyright 1992-2002 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -111,7 +111,7 @@ mFunc_Include( tTemplate* pT, tMacro* pMac )
 mLoad_Include( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 {
     if ((int)pMac->res == 0)
-        LOAD_ABORT( pT, pMac, "The INCLUDE macro requires a file name" );
+        AG_ABEND_IN( pT, pMac, "The INCLUDE macro requires a file name" );
     return mLoad_Expr( pT, pMac, ppzScan );
 }
 
@@ -135,7 +135,7 @@ mLoad_Include( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 mFunc_Unknown( tTemplate* pT, tMacro* pMac )
 {
     tTemplate* pInv = findTemplate( pT->pzTemplText + pMac->ozName );
-    if (pInv != (tTemplate*)NULL) {
+    if (pInv != NULL) {
         if (OPT_VALUE_TRACE >= TRACE_EVERYTHING)
             fprintf( pfTrace, zTrcFmt, "remapped to Define", pMac->funcCode,
                      pT->pzFileName, pMac->lineNo );
@@ -197,7 +197,7 @@ mFunc_Bogus( tTemplate* pT, tMacro* pMac )
     tSCC z[] = "%d (%s) is an unknown macro function, or has no handler";
     char* pz = asprintf( z, pMac->funcCode, (pMac->funcCode < FUNC_CT)
                          ? apzFuncNames[ pMac->funcCode ] : "??" );
-    fprintf( stderr, zTplErr, pT->pzFileName, pMac->lineNo, pz );
+    AG_ABEND_IN( pT, pMac, pz );
     longjmp( fileAbort, FAILURE );
     return pMac;
 }
@@ -302,7 +302,7 @@ mLoad_Unknown( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
          */
         remLen = canonicalizeName( pzCopy, pzSrc, srcLen );
         if (remLen > srcLen)
-            LOAD_ABORT( pT, pMac, "Invalid definition name" );
+            AG_ABEND_IN( pT, pMac, "Invalid definition name" );
 
         pzSrc  += srcLen - remLen;
         srcLen  = remLen;
@@ -349,26 +349,18 @@ mLoad_Unknown( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     tMacro*
 mLoad_Bogus( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 {
-    const char*    pzSrc  = (const char*)pMac->ozText; /* macro text */
-    long           srcLen = (long)pMac->res;           /* macro len  */
-    char z[ 128 ];
-    snprintf( z, sizeof(z), "%s function (%d) out of context",
-              apzFuncNames[ pMac->funcCode ], pMac->funcCode );
-    fprintf( stderr, zTplErr, pT->pzFileName,
-             pMac->lineNo, z );
+    tCC* pzSrc = (const char*)pMac->ozText; /* macro text */
+    char z[ 64 ];
 
-    if (srcLen > 0) {
-        if (srcLen > 64)
-            srcLen = 64;
-        do  {
-            fputc( *(pzSrc++), stderr );
-        } while (--srcLen > 0);
-        fputc( '\n', stderr );
-    }
+    strncpy( z, pzSrc, 63 );
+    z[63] = NUL;
 
-    LOAD_ABORT( pT, pMac, "bad context" );
+    pzSrc = asprintf( "Unknown macro or invalid context in %s line %d:\n\t%s",
+                      pT->pzFileName, pMac->lineNo, z );
+
+    AG_ABEND_IN( pT, pMac, pzSrc );
     /* NOTREACHED */
-    return (tMacro*)NULL;
+    return NULL;
 }
 /*
  * Local Variables:
