@@ -1,12 +1,12 @@
 
 /*
- *  $Id: loadPseudo.c,v 1.16 2001/07/21 18:20:25 bkorb Exp $
+ *  $Id: loadPseudo.c,v 3.5 2002/02/01 03:36:35 bkorb Exp $
  *
  *  This module processes the "pseudo" macro
  */
 
 /*
- *  AutoGen copyright 1992-1999 Bruce Korb
+ *  AutoGen copyright 1992-2002 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -52,7 +52,7 @@ tSCC zTpName[] = "template";
  *
  *  Process a scheme specification
  */
-    STATIC tCC*
+STATIC tCC*
 doSchemeExpr( tCC* pzData, tCC* pzFileName, int lineNo )
 {
     char* pzEnd = (char*)pzData + strlen( pzData );
@@ -73,7 +73,7 @@ doSchemeExpr( tCC* pzData, tCC* pzFileName, int lineNo )
  *
  *  Process a suffix specification
  */
-    EXPORT tCC*
+EXPORT tCC*
 doSuffixSpec( tCC* pzData, tCC* pzFileName, int lineNo )
 {
     /*
@@ -116,7 +116,7 @@ doSuffixSpec( tCC* pzData, tCC* pzFileName, int lineNo )
      */
     *ppOSList  = pOS;
     ppOSList   = &pOS->pNext;
-    pOS->pNext = (tOutSpec*)NULL;
+    pOS->pNext = NULL;
 
     /*
      *  Copy the data into the suffix field from our input buffer.
@@ -129,7 +129,7 @@ doSuffixSpec( tCC* pzData, tCC* pzFileName, int lineNo )
 
     pz = strchr( pOS->zSuffix, '=' );
 
-    if (pz != (char*)NULL) {
+    if (pz != NULL) {
         tSCC zFileFmt3[] = "%s";
         *pz++ = NUL;
         if (*pz == NUL)
@@ -160,7 +160,7 @@ doSuffixSpec( tCC* pzData, tCC* pzFileName, int lineNo )
  *  Skiping leading white space, figure out what sort of token is under
  *  the scan pointer (pzData).
  */
-    STATIC te_pm_event
+STATIC te_pm_event
 findTokenType( tCC**  ppzData, te_pm_state fsm_state, ag_bool line_start )
 {
     tCC* pzData = *ppzData;
@@ -233,7 +233,7 @@ findTokenType( tCC**  ppzData, te_pm_state fsm_state, ag_bool line_start )
      */
     if ((*pzData == '#') && line_start) {
         pzData = strchr( pzData+1, '\n' );
-        if (pzData == (char*)NULL)
+        if (pzData == NULL)
             return PM_EV_INVALID;
 
         goto skipWhiteSpace;
@@ -267,7 +267,7 @@ findTokenType( tCC**  ppzData, te_pm_state fsm_state, ag_bool line_start )
  *  Some sort of marker is under the scan pointer.  Copy it for as long
  *  as we find punctuation characters.
  */
-    STATIC tCC*
+STATIC tCC*
 copyMarker( tCC* pzData, char* pzMark, int* pCt )
 {
     int ct = 0;
@@ -278,7 +278,7 @@ copyMarker( tCC* pzData, char* pzMark, int* pCt )
             break;
         *(pzMark++) = ch;
         if (++ct >= sizeof( zStartMac ))
-            return (tCC*)NULL;
+            return NULL;
 
         pzData++;
     }
@@ -296,12 +296,14 @@ copyMarker( tCC* pzData, char* pzMark, int* pCt )
  *  Using a finite state machine, scan over the tokens that make up the
  *  "pseudo macro" at the start of every template.
  */
-    EXPORT tCC*
+EXPORT tCC*
 loadPseudoMacro( tCC* pzData, tCC* pzFileName )
 {
     tSCC zMarkErr[] = "start/end macro mark too long";
+    tSCC zBadMark[] = "bad template marker in %s on line %d:\n\t%s";
 #   define BAD_MARKER( t ) STMTS( \
-        fprintf( stderr, zTplErr, pzFileName, templLineNo, t ); AG_ABEND; )
+            char* pz = asprintf( zBadMark, pzFileName, templLineNo, t ); \
+            AG_ABEND( pz ); )
 
     te_pm_state fsm_state  = PM_ST_INIT;
     ag_bool      line_start = AG_TRUE;  /* set TRUE first time only */
@@ -343,7 +345,7 @@ loadPseudoMacro( tCC* pzData, tCC* pzFileName )
 
         case PM_TR_INIT_MARKER:
             pzData = copyMarker( pzData, zStartMac, &startMacLen );
-            if (pzData == (tCC*)NULL)
+            if (pzData == NULL)
                 BAD_MARKER( zMarkErr );
 
             break;
@@ -354,7 +356,7 @@ loadPseudoMacro( tCC* pzData, tCC* pzFileName )
 
         case PM_TR_TEMPL_MARKER:
             pzData = copyMarker( pzData, zEndMac, &endMacLen );
-            if (pzData == (tCC*)NULL)
+            if (pzData == NULL)
                 BAD_MARKER( zMarkErr );
 
             /*
@@ -411,6 +413,8 @@ loadPseudoMacro( tCC* pzData, tCC* pzFileName )
     if (serverArgs[0] != NULL) {
         char* pz = getenv( "SHELL" );
         if ((pz != NULL) && (strcmp( pz, serverArgs[0] ) != 0)) {
+            fprintf( pfTrace, "Changing server shell from %s to %s\n",
+                     serverArgs[0], pz );
             closeServer();
             serverArgs[0] = pz;
         }
@@ -421,5 +425,6 @@ loadPseudoMacro( tCC* pzData, tCC* pzFileName )
 /*
  * Local Variables:
  * c-file-style: "stroustrup"
+ * indent-tabs-mode: nil
  * End:
  * end of loadPseudo.c */
