@@ -1,9 +1,15 @@
-/*
- * AutoGen Globally exported prototypes Sat Dec  1 20:58:46 PST 2001
+/* -*- buffer-read-only: t -*- vi: set ro:
+ *
+ * AutoGen Globally exported prototypes Mon Feb  4 20:35:30 PST 2002
  */
 #ifndef AUTOGEN_PROTOTYPES_H
 #define AUTOGEN_PROTOTYPES_H
 
+/* exports from agCgi.c */
+
+void
+loadCgi( void );
+
 /* exports from agShell.c */
 
 void
@@ -36,6 +42,13 @@ skipScheme( tCC* pzSrc,  tCC* pzEnd );
 tCC*
 skipExpression( tCC* pzSrc, size_t len );
 
+/* exports from autogen.c */
+
+void
+ag_abend_at( tCC* pzMsg, tCC* pzFile, int line );
+void
+ag_abend( tCC* pzMsg );
+
 /* exports from defDirect.c */
 
 char*
@@ -128,11 +141,6 @@ tTemplate*
 findTemplate( tCC* pzTemplName );
 tSuccess
 findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList );
-void
-loadMacros( tTemplate*     pT,
-            tCC*    pzF,
-            tCC*    pzN,
-            tCC*    pzData );
 tTemplate*
 templateFixup( tTemplate* pTList, size_t ttlSize );
 void
@@ -143,7 +151,7 @@ loadTemplate( tCC* pzFileName );
 /* exports from tpParse.c */
 
 tMacro*
-parseTemplate( tTemplate* pT, tMacro* pM, tCC** ppzText );
+parseTemplate( tMacro* pM, tCC** ppzText );
 
 /* exports from tpProcess.c */
 
