@@ -1,12 +1,12 @@
 
 /*
- *  $Id: tpLoad.c,v 1.20 2001/06/24 00:53:08 bkorb Exp $
+ *  $Id: tpLoad.c,v 3.8 2002/01/31 02:29:13 bkorb Exp $
  *
  *  This module will load a template and return a template structure.
  */
 
 /*
- *  AutoGen copyright 1992-1999 Bruce Korb
+ *  AutoGen copyright 1992-2002 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -37,11 +37,11 @@ static tTlibMark magicMark = TEMPLATE_MAGIC_MARKER;
 STATIC size_t countMacros( tCC* pz );
 
 
-    EXPORT tTemplate*
+EXPORT tTemplate*
 findTemplate( tCC* pzTemplName )
 {
     tTemplate* pT = pNamedTplList;
-    while (pT != (tTemplate*)NULL) {
+    while (pT != NULL) {
         if (streqvcmp( pzTemplName, pT->pzTplName ) == 0)
             break;
         pT = (tTemplate*)(pT->pNext);
@@ -49,17 +49,30 @@ findTemplate( tCC* pzTemplName )
     return pT;
 }
 
+STATIC ag_bool
+canReadFile( tCC* pzFName )
+{
+    struct stat stbf;
+    if (stat( pzFName, &stbf ) != 0)
+        return AG_FALSE;
+    if (! S_ISREG( stbf.st_mode ))
+        return AG_FALSE;
+    return (access( pzFName, R_OK) == 0);
+}
+
+
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
  *  Starting with the current directory, search the directory
  *  list trying to find the base template file name.
  */
-    EXPORT tSuccess
+EXPORT tSuccess
 findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList )
 {
     char*   pzRoot;
     char*   pzSfx;
     void*   deallocAddr = NULL;
+
     tSuccess res = SUCCESS;
 
     /*
@@ -84,7 +97,7 @@ findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList )
     /*
      *  Check for an immediately accessible file
      */
-    if (access( pzFName, R_OK ) == 0) {
+    if (canReadFile( pzFName )) {
         strlcpy( pzFullName, pzFName, MAXPATHLEN );
         goto findFileReturn;
     }
@@ -95,7 +108,7 @@ findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList )
      *  Check for immediate access once again.
      */
     pzRoot = strrchr( pzFName, '/' );
-    pzSfx  = (pzRoot != (char*)NULL)
+    pzSfx  = (pzRoot != NULL)
              ? strchr( ++pzRoot, '.' )
              : strchr( pzFName, '.' );
 
@@ -103,7 +116,7 @@ findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList )
      *  IF the file does not already have a suffix,
      *  THEN try the suffixes that are okay for this file.
      */
-    if ((pzSfx == (char*)NULL) && (papSuffixList != NULL)) {
+    if ((pzSfx == NULL) && (papSuffixList != NULL)) {
         tCC** papSL = papSuffixList;
 
         char* pzEnd = pzFullName +
@@ -111,7 +124,7 @@ findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList )
 
         do  {
             strcpy( pzEnd, *(papSL++) ); /* must fit */
-            if (access( pzFullName, R_OK ) == 0) {
+            if (canReadFile( pzFullName )) {
                 goto findFileReturn;
             }
         } while (*papSL != NULL);
@@ -121,7 +134,7 @@ findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList )
      *  IF the file name does not contain a directory separator,
      *  then we will use the TEMPL_DIR search list to keep hunting.
      */
-    if (pzRoot == (char*)NULL) {
+    if (pzRoot == NULL) {
 
         /*
          *  Search each directory in our directory search list
@@ -153,20 +166,20 @@ findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList )
                 + snprintf( pzFullName, MAXPATHLEN-MAX_SUFFIX_LEN,
                             zDirFmt, pzDir, pzFName );
 
-            if (access( pzFullName, R_OK ) == 0)
+            if (canReadFile( pzFullName ))
                 goto findFileReturn;
 
             /*
              *  IF the file does not already have a suffix,
              *  THEN try the ones that are okay for this file.
              */
-            if ((pzSfx == (char*)NULL) && (papSuffixList != NULL)) {
+            if ((pzSfx == NULL) && (papSuffixList != NULL)) {
                 tCC** papSL = papSuffixList;
                 *(pzEnd++) = '.';
 
                 do  {
                     strcpy( pzEnd, *(papSL++) ); /* must fit */
-                    if (access( pzFullName, R_OK ) == 0)
+                    if (canReadFile( pzFullName ))
                         goto findFileReturn;
 
                 } while (*papSL != NULL);
@@ -191,13 +204,13 @@ findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList )
  *  Figure out how many macros there are in the template
  *  so that we can allocate the right number of pointers.
  */
-    STATIC size_t
+STATIC size_t
 countMacros( tCC* pz )
 {
     size_t  ct = 2;
     for (;;) {
         pz = strstr( pz, zStartMac );
-        if (pz == (char*)NULL)
+        if (pz == NULL)
             break;
         ct += 2;
         if (strncmp( pz - endMacLen, zEndMac, endMacLen ) == 0)
@@ -214,11 +227,11 @@ countMacros( tCC* pz )
  *
  *  Load the macro array and file name.
  */
-    EXPORT void
-loadMacros( tTemplate*     pT,
-            tCC*    pzF,
-            tCC*    pzN,
-            tCC*    pzData )
+STATIC void
+loadMacros( tTemplate* pT,
+            tCC*       pzF,
+            tCC*       pzN,
+            tCC*       pzData )
 {
     tMacro* pMac   = pT->aMacros;
 
@@ -230,7 +243,7 @@ loadMacros( tTemplate*     pT,
         len = strlen( pzF ) + 1;
         memcpy( (void*)pzText, (void*)pzF, len );
         pzText += len;
-        if (pzN != (char*)NULL) {
+        if (pzN != NULL) {
             len = strlen( pzN ) + 1;
             memcpy( (void*)pzText, (void*)pzN, len );
             pzText += len;
@@ -240,17 +253,16 @@ loadMacros( tTemplate*     pT,
         pT->pNext = pzText + 1;
     }
 
+    pCurTemplate = pT;
+
     {
-        tMacro* pMacEnd = parseTemplate( pT, pMac, &pzData );
+        tMacro* pMacEnd = parseTemplate( pMac, &pzData );
 
         /*
          *  Make sure all of the input string was scanned.
          */
-        if (pzData != (char*)NULL)  {
-            fprintf( stderr, zTplErr, pzF, -1,
-                     "parse ended unexpectedly" );
-            AG_ABEND;
-        }
+        if (pzData != NULL)
+            AG_ABEND( "Template parse ended unexpectedly" );
 
         pT->macroCt = pMacEnd - pMac;
 
@@ -284,11 +296,11 @@ loadMacros( tTemplate*     pT,
      *  the entries are all linked together and
      *  realloc-ing it may cause it to move.
      */
-#if defined( DEBUG ) && defined( VALUE_OPT_SHOW_DEFS )
+#if defined( DEBUG )
     if (HAVE_OPT( SHOW_DEFS )) {
         tSCC zSum[] = "loaded %d macros from %s\n"
             "\tBinary template size:  0x%X\n\n";
-        printf( zSum, pT->macroCt, pzF, pT->descSize );
+        fprintf( pfTrace, zSum, pT->macroCt, pzF, pT->descSize );
     }
 #endif
 }
@@ -298,7 +310,7 @@ loadMacros( tTemplate*     pT,
  *
  *  Convert a template from data file format to internal format.
  */
-    EXPORT tTemplate*
+EXPORT tTemplate*
 templateFixup( tTemplate* pTList, size_t ttlSize )
 {
     tTemplate* pT = pTList;
@@ -318,14 +330,9 @@ templateFixup( tTemplate* pTList, size_t ttlSize )
         pT->fd    = 0;
         pT->pNext = (char*)pT + tplSize;
         pT = (tTemplate*)(pT->pNext);
-        if (memcmp( (void*)pT, (void*)pTList, sizeof( tTlibMark )) != 0) {
-            tSCC z[] = "The %s binary template library is inconsistent\n";
-            fprintf( stderr, z, pTList->pzFileName );
-            AG_ABEND;
-        }
     }
 
-    pT->pNext = (char*)NULL;
+    pT->pNext = NULL;
     return pTList;
 }
 
@@ -335,39 +342,35 @@ templateFixup( tTemplate* pTList, size_t ttlSize )
  *  Starting with the current directory, search the directory
  *  list trying to find the base template file name.
  */
-    EXPORT void
+EXPORT void
 mapDataFile( tCC* pzFileName, tMapInfo* pMapInfo, tCC** papSuffixList )
 {
+    tSCC zOpen[] = "open";
+
     static char  zRealFile[ MAXPATHLEN ];
 
     /*
      *  Find the template file somewhere
      */
-    if (! SUCCESSFUL( findFile( pzFileName, zRealFile, papSuffixList ))) {
-        tSCC zMapDataFile[] = "map data file";
-        fprintf( stderr, zCannot, pzProg, ENOENT,
-                 zMapDataFile, pzFileName, strerror( ENOENT ));
-        AG_ABEND;
-    }
+    if (! SUCCESSFUL( findFile( pzFileName, zRealFile, papSuffixList )))
+        AG_ABEND( asprintf( zCannot, ENOENT, "map data file",
+                            pzFileName, strerror( ENOENT )));
+
     AGDUPSTR( pMapInfo->pzFileName, zRealFile, "map data file" );
 
     /*
      *  The template file must really be a file.
      */
     {
+        char* pz;
         struct stat stbf;
-        if (stat( zRealFile, &stbf ) != 0) {
-            tSCC zStat[] = "stat";
-            fprintf( stderr, zCannot, pzProg, errno,
-                     zStat, zRealFile, strerror( errno ));
-            AG_ABEND;
-        }
+        if (stat( zRealFile, &stbf ) != 0)
+            AG_ABEND( asprintf( zCannot, errno, zOpen,
+                                zRealFile, strerror( errno )));
 
-        if (! S_ISREG( stbf.st_mode )) {
-            fprintf( stderr, "ERROR:  `%s' is not a regular file\n",
-                     zRealFile );
-            AG_ABEND;
-        }
+        if (! S_ISREG( stbf.st_mode ))
+            AG_ABEND( asprintf( zCannot, errno, zOpen,
+                                zRealFile, "wrong file type" ));
 
         if (outTime <= stbf.st_mtime)
             outTime = stbf.st_mtime + 1;
@@ -378,23 +381,17 @@ mapDataFile( tCC* pzFileName, tMapInfo* pMapInfo, tCC** papSuffixList )
      *  Now open it and map it into memory
      */
     pMapInfo->fd = open( zRealFile, O_EXCL | O_RDONLY, 0 );
-    if (pMapInfo->fd == -1) {
-        tSCC zOpen[] = "open";
-        fprintf( stderr, zCannot, pzProg, errno,
-                 zOpen, zRealFile, strerror( errno ));
-        AG_ABEND;
-    }
+    if (pMapInfo->fd == -1)
+        AG_ABEND( asprintf( zCannot, errno, zOpen,
+                            zRealFile, strerror( errno )));
 
     pMapInfo->pData =
-        mmap( (void*)NULL, pMapInfo->size, PROT_READ | PROT_WRITE,
+        mmap( NULL, pMapInfo->size, PROT_READ | PROT_WRITE,
               MAP_PRIVATE, pMapInfo->fd, (off_t)0 );
 
-    if (pMapInfo->pData == (void*)(-1)) {
-        tSCC zMmap[] = "mmap";
-        fprintf( stderr, zCannot, pzProg, errno,
-                 zMmap, zRealFile, strerror( errno ));
-        AG_ABEND;
-    }
+    if (pMapInfo->pData == (void*)(-1))
+        AG_ABEND( asprintf( zCannot, errno, "mmap",
+                            zRealFile, strerror( errno )));
 }
 
 
@@ -403,7 +400,7 @@ mapDataFile( tCC* pzFileName, tMapInfo* pMapInfo, tCC** papSuffixList )
  *  Starting with the current directory, search the directory
  *  list trying to find the base template file name.
  */
-    EXPORT tTemplate*
+EXPORT tTemplate*
 loadTemplate( tCC* pzFileName )
 {
     tSCC*        apzSfx[] = { "tpl", "agl", NULL };
@@ -411,39 +408,12 @@ loadTemplate( tCC* pzFileName )
 
     mapDataFile( pzFileName, &mapInfo, apzSfx );
 
-    /*
-     *  Check for a binary template.  If it is, it must
-     *  be the current revision, or we choke.
-     */
-    {
-        tTemplate*  p = (tTemplate*)mapInfo.pData;
-
-        if (p->magic.magic.i[0] == magicMark.magic.i[0]) {
-            tSCC zOutOfDate[] = "out-of-date binary template";
-            tSCC zTooNew[]    = "unknown binary template version";
-            tSCC zChange[]    = "Functions changed - rebuild lib";
-            tCC* pz;
-
-            if (p->magic.magic.i[1] == magicMark.magic.i[1]) {
-                p->fd = mapInfo.fd;
-                return templateFixup( p, mapInfo.size-1 );
-            }
-
-            if (p->magic.revision < TEMPLATE_REVISION)
-                pz = zOutOfDate;
-            if (p->magic.revision > TEMPLATE_REVISION)
-                pz = zTooNew;
-            else
-                pz = zChange;
-
-            fprintf( stderr, zTplErr, mapInfo.pzFileName, 0, pz );
-            AG_ABEND;
-        }
-    }
-
     {
         size_t       macroCt;
+        tTemplate    tmpTpl;
         tTemplate*   pRes;
+        tTemplate*   pSaveTpl = pCurTemplate;
+        tMacro*      pSaveMac = pCurMacro;
         size_t       alocSize;
         tCC*         pzData;
 
@@ -451,6 +421,9 @@ loadTemplate( tCC* pzFileName )
          *  Process the leading pseudo-macro.  The template proper
          *  starts immediately after it.
          */
+        pCurMacro    = NULL;
+        pCurTemplate = &tmpTpl;
+        tmpTpl.pzFileName = mapInfo.pzFileName;
         pzData = loadPseudoMacro( (tCC*)mapInfo.pData, mapInfo.pzFileName );
 
         /*
@@ -476,13 +449,16 @@ loadTemplate( tCC* pzFileName )
         pRes->fd        = -1;
         strcpy( pRes->zStartMac, zStartMac ); /* must fit */
         strcpy( pRes->zEndMac, zEndMac );     /* must fit */
-        loadMacros( pRes, mapInfo.pzFileName, (char*)NULL, pzData );
+        loadMacros( pRes, mapInfo.pzFileName, NULL, pzData );
         pRes = (tTemplate*)AGREALOC( (void*)pRes, pRes->descSize,
-                                     "resize main template" );
+                                     "resize template" );
 
         munmap( mapInfo.pData, mapInfo.size );
         close( mapInfo.fd );
-        return templateFixup( pRes, pRes->descSize );
+        pRes = templateFixup( pRes, pRes->descSize );
+        pCurTemplate = pSaveTpl;
+        pCurMacro    = pSaveMac;
+        return pRes;
     }
 }
 
@@ -505,5 +481,6 @@ unloadTemplate( tTemplate* pT )
 /*
  * Local Variables:
  * c-file-style: "stroustrup"
+ * indent-tabs-mode: nil
  * End:
  * end of tpLoad.c */
