@@ -2,13 +2,13 @@
 /*
  *  tpParse.c
  *
- *  $Id: tpParse.c,v 1.9 2001/08/17 03:16:18 bkorb Exp $
+ *  $Id: tpParse.c,v 3.5 2002/01/19 07:35:24 bkorb Exp $
  *
  *  This module will load a template and return a template structure.
  */
 
 /*
- *  AutoGen copyright 1992-1999 Bruce Korb
+ *  AutoGen copyright 1992-2002 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -30,17 +30,16 @@
 #define LOAD_FUNCTIONS
 #include "autogen.h"
 
-STATIC teFuncType whichFunc( tTemplate* pT, tMacro* pMac,
-                             const char** ppzScan );
-STATIC tCC* findMacroEnd( tTemplate* pT, tMacro* pM, tCC** ppzMark );
+STATIC teFuncType whichFunc( tCC** ppzScan );
+STATIC tCC* findMacroEnd( tCC** ppzMark );
 
 
 /*
  *  Return the enumerated function type corresponding
  *  to a name pointed to by the input argument.
  */
-    STATIC teFuncType
-whichFunc( tTemplate* pT, tMacro* pMac, const char** ppzScan )
+STATIC teFuncType
+whichFunc( tCC** ppzScan )
 {
     const char*   pzFuncName = *ppzScan;
     int           hi, lo, av;
@@ -106,14 +105,14 @@ whichFunc( tTemplate* pT, tMacro* pMac, const char** ppzScan )
     /*
      *  Save the name for later lookup
      */
-    pMac->ozName = (pT->pNext - pT->pzTemplText);
+    pCurMacro->ozName = (pCurTemplate->pNext - pCurTemplate->pzTemplText);
     {
-        char* pzCopy = pT->pNext;
+        char* pzCopy = pCurTemplate->pNext;
         while (ISNAMECHAR( *pzFuncName ))
             *(pzCopy++) = *(pzFuncName++);
         *(pzCopy++) = '\0';
         *ppzScan = pzFuncName;
-        pT->pNext = pzCopy;
+        pCurTemplate->pNext = pzCopy;
     }
 
     /*
@@ -126,8 +125,8 @@ whichFunc( tTemplate* pT, tMacro* pMac, const char** ppzScan )
 }
 
 
-    STATIC tCC*
-findMacroEnd( tTemplate* pT, tMacro* pM, tCC** ppzMark )
+STATIC tCC*
+findMacroEnd( tCC** ppzMark )
 {
     tCC* pzMark = *ppzMark + startMacLen;
     tCC* pzNextMark;
@@ -143,31 +142,32 @@ findMacroEnd( tTemplate* pT, tMacro* pM, tCC** ppzMark )
             templLineNo++;
     }
 
-    pM->funcCode = whichFunc( pT, pM, &pzMark );
-    pM->lineNo   = templLineNo;
+    pCurMacro->funcCode = whichFunc( &pzMark );
+    pCurMacro->lineNo   = templLineNo;
     *ppzMark     = pzMark;
 
     pzEndMark = strstr( pzMark, zEndMac );
-	if (pzEndMark == (char*)NULL)
-		LOAD_ABORT( pT, pM, "macro has no end" );
+	if (pzEndMark == NULL)
+		AG_ABEND( "macro has no end" );
 
 	pzNextMark = strstr( pzMark, zStartMac );
 	if (pzNextMark == NULL)
 		return pzEndMark;
 
 	if (pzEndMark > pzNextMark)
-		LOAD_ABORT( pT, pM, "macros cannot nest" );
+		AG_ABEND( "macros cannot nest" );
 
 	return pzEndMark;
 }
 
 
-    EXPORT tMacro*
-parseTemplate( tTemplate* pT, tMacro* pM, tCC** ppzText )
+EXPORT tMacro*
+parseTemplate( tMacro* pM, tCC** ppzText )
 {
     tCC* pzScan = *ppzText;
+    tTemplate* pT = pCurTemplate;
 
-#if defined( DEBUG ) && defined( VALUE_OPT_SHOW_DEFS )
+#if defined( DEBUG )
     tSCC zTDef[]   = "%-10s (%d) line %d end=%d, strlen=%d\n";
     tSCC zTUndef[] = "%-10s (%d) line %d - MARKER\n";
 
@@ -179,11 +179,11 @@ parseTemplate( tTemplate* pT, tMacro* pM, tCC** ppzText )
         int ct = level;
         tMacro* pPm = pM-1;
 
-        printf( "%3d ", pPm - pT->aMacros );
-        do { fputs( "  ", stdout ); } while (--ct > 0);
+        fprintf( pfTrace, "%3d ", pPm - pT->aMacros );
+        do { fputs( "  ", pfTrace ); } while (--ct > 0);
 
-        printf( zTUndef, apzFuncNames[ pPm->funcCode ], pPm->funcCode,
-                pPm->lineNo );
+        fprintf( pfTrace, zTUndef, apzFuncNames[ pPm->funcCode ],
+                 pPm->funcCode, pPm->lineNo );
     }
 #else
     #define DEBUG_DEC(l)
@@ -196,20 +196,23 @@ parseTemplate( tTemplate* pT, tMacro* pM, tCC** ppzText )
          *  IF there is any text, then make a text macro entry
          */
         if (pzMark != pzScan) {
-            char* pzCopy = pT->pNext;
-            const char* pzEnd = (pzMark != (char*)NULL)
-                                ? pzMark : pzScan + strlen( pzScan );
+            char* pzCopy;
+            const char* pzEnd;
+
+            pzCopy = pT->pNext;
+            pzEnd = (pzMark != NULL)
+                ? pzMark : pzScan + strlen( pzScan );
 
             pM->ozText    = pzCopy - pT->pzTemplText;
             pM->funcCode  = FTYP_TEXT;
             pM->lineNo    = templLineNo;
-#if defined( DEBUG ) && defined( VALUE_OPT_SHOW_DEFS )
+#if defined( DEBUG )
             if (HAVE_OPT( SHOW_DEFS )) {
                 int ct = level;
-                printf( "%3d ", pM - pT->aMacros );
-                do { fputs( "  ", stdout ); } while (--ct > 0);
+                fprintf( pfTrace, "%3d ", pM - pT->aMacros );
+                do { fputs( "  ", pfTrace ); } while (--ct > 0);
 
-                printf( zTDef, apzFuncNames[ FTYP_TEXT ], FTYP_TEXT,
+                fprintf( pfTrace, zTDef, apzFuncNames[ FTYP_TEXT ], FTYP_TEXT,
                         pM->lineNo, pM->endIndex,
                         pzEnd - pzScan );
             }
@@ -227,13 +230,14 @@ parseTemplate( tTemplate* pT, tMacro* pM, tCC** ppzText )
          *  IF no more macro marks are found,
          *  THEN we are done...
          */
-        if (pzMark == (char*)NULL)
+        if (pzMark == NULL)
             break;
 
         /*
          *  Find the macro code and the end of the macro invocation
          */
-        pzScan = findMacroEnd( pT, pM, &pzMark );
+        pCurMacro = pM;
+        pzScan = findMacroEnd( &pzMark );
 
         /*
          *  Count the lines in the macro text and advance the
@@ -245,7 +249,7 @@ parseTemplate( tTemplate* pT, tMacro* pM, tCC** ppzText )
 
             for (;;pz++) {
                 pz = strchr( pz, '\n' );
-                if ((pz == (char*)NULL) || (pz > pzMacEnd))
+                if ((pz == NULL) || (pz > pzMacEnd))
                     break;
                 templLineNo++;
             }
@@ -269,7 +273,7 @@ parseTemplate( tTemplate* pT, tMacro* pM, tCC** ppzText )
          *       will be non-NULL.
          */
         {
-#if ! defined( DEBUG ) || ! defined( VALUE_OPT_SHOW_DEFS )
+#if ! defined( DEBUG )
             tMacro* pNM = (*(papLoadProc[ pM->funcCode ]))( pT, pM, &pzScan );
 #else
             teFuncType ft = pM->funcCode;
@@ -279,22 +283,22 @@ parseTemplate( tTemplate* pT, tMacro* pM, tCC** ppzText )
             if (HAVE_OPT( SHOW_DEFS )) {
                 int ct = level;
                 if (pM->funcCode == FTYP_BOGUS)
-                     fputs( "    ", stdout );
-                else printf( "%3d ", pM - pT->aMacros );
+                     fputs( "    ", pfTrace );
+                else fprintf( pfTrace, "%3d ", pM - pT->aMacros );
 
-                do { fputs( "  ", stdout ); } while (--ct > 0);
+                do { fputs( "  ", pfTrace ); } while (--ct > 0);
 
                 if (pM->funcCode == FTYP_BOGUS)
-                     printf( zTUndef, apzFuncNames[ ft ], ft, ln );
+                     fprintf( pfTrace, zTUndef, apzFuncNames[ ft ], ft, ln );
                 else
-                    printf( zTDef, apzFuncNames[ ft ], pM->funcCode, ln,
-                            pM->endIndex,
-                            strlen( (pM->ozText == 0) ? ""
-                                    : (pT->pzTemplText + pM->ozText) ));
+                    fprintf( pfTrace, zTDef, apzFuncNames[ ft ], pM->funcCode,
+                             ln, pM->endIndex,
+                             strlen( (pM->ozText == 0) ? ""
+                                     : (pT->pzTemplText + pM->ozText) ));
             }
 #endif
 
-            if (pNM == (tMacro*)NULL) {
+            if (pNM == NULL) {
                 *ppzText = pzScan;
                 DEBUG_DEC(level);
                 return pM;
@@ -309,7 +313,7 @@ parseTemplate( tTemplate* pT, tMacro* pM, tCC** ppzText )
      *  We reached the end of the input string.
      *  Return a NULL scanning pointer and a pointer to the end.
      */
-    *ppzText = (const char*)NULL;
+    *ppzText = NULL;
     return pM;
 }
 /*
