@@ -1,6 +1,6 @@
 
 /*
- *  $Id: autoopts.c,v 2.36 2001/11/21 06:00:41 bkorb Exp $
+ *  $Id: autoopts.c,v 3.2 2001/12/10 01:13:09 bkorb Exp $
  *
  *  This file contains all of the routines that must be linked into
  *  an executable to use the generated option processing.  The optional
@@ -9,7 +9,7 @@
  */
 
 /*
- *  Automated Options copyright 1992-1999 Bruce Korb
+ *  Automated Options copyright 1992-2001 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -280,7 +280,7 @@ longOptionFind( pOpts, pzOptName, pOptState )
         if (disable)
             pOptState->flags |= OPTST_DISABLED;
 
-        pOptState->pOD = pOpts->pOptDesc + matchIdx;
+        pOptState->pOD      = pOpts->pOptDesc + matchIdx;
         pOptState->pzOptArg = pzEq;
         pOptState->optType  = TOPT_LONG;
         return SUCCESS;
@@ -339,7 +339,7 @@ shortOptionFind( pOpts, optValue, pOptState )
          *  THEN we stop here
          */
         if ((! SKIP_OPT(pRes)) && (optValue == pRes->optValue)) {
-            pOptState->pOD = pRes;
+            pOptState->pOD     = pRes;
             pOptState->optType = TOPT_SHORT;
             return SUCCESS;
         }
@@ -364,7 +364,8 @@ shortOptionFind( pOpts, optValue, pOptState )
      */
     if (  isdigit( optValue )
        && (pOpts->specOptIdx.number_option != NO_EQUIVALENT) ) {
-        pOptState->pOD = pOpts->pOptDesc + pOpts->specOptIdx.number_option;
+        pOptState->pOD = \
+        pRes           = pOpts->pOptDesc + pOpts->specOptIdx.number_option;
         (pOpts->pzCurOpt)--;
         pOptState->optType = TOPT_SHORT;
         return SUCCESS;
@@ -388,7 +389,8 @@ shortOptionFind( pOpts, optValue, pOptState )
  *
  *  Find the option descriptor for the current option
  */
-STATIC tSuccess findOptDesc( pOpts, pOptState )
+STATIC tSuccess
+findOptDesc( pOpts, pOptState )
     tOptions*  pOpts;
     tOptState* pOptState;
 {
@@ -469,15 +471,17 @@ STATIC tSuccess findOptDesc( pOpts, pOptState )
  *  all the state in the state argument so that the option can be skipped
  *  without consequence (side effect).
  */
-DEF_PROC_2( STATIC tSuccess nextOption,
-            tOptions*,   pOpts,
-            tOptState*,  pOptState )
+STATIC tSuccess
+nextOption( pOpts, pOptState )
+    tOptions*   pOpts;
+    tOptState*  pOptState;
 {
     tSuccess res;
 
     res = findOptDesc( pOpts, pOptState );
     if (! SUCCESSFUL( res ))
         return res;
+    pOptState->flags |= (pOptState->pOD->fOptState & OPTST_PERSISTENT);
 
     /*
      *  Figure out what to do about option arguments.  An argument may be
@@ -817,16 +821,20 @@ doImmediateOpts( pOpts )
             goto optionsDone;
 
         case PROBLEM:
-            return 0; /* no more args */
+            /*
+             *  FIXME:  Here is where we have to worry about how to reorder
+             *          arguments.  Not today.
+             */
+            return SUCCESS; /* no more args */
 
         case SUCCESS:
             break;
         }
 
         /*
-         *  IF this is not an immediate-attribute option, then do it.
+         *  IF this *is* an immediate-attribute option, then do it.
          */
-        switch (optState.pOD->fOptState & (OPTST_DISABLE_IMM|OPTST_IMM)) {
+        switch (optState.flags & (OPTST_DISABLE_IMM|OPTST_IMM)) {
         case 0:                   /* never */
             continue;
 
@@ -854,11 +862,12 @@ doImmediateOpts( pOpts )
 }
 
 
-DEF_PROC_4( STATIC void loadOptionLine,
-            tOptions*,  pOpts,
-            tOptState*, pOS,
-            char*,      pzLine,
-            tDirection, direction )
+STATIC void
+loadOptionLine( pOpts, pOS, pzLine, direction )
+    tOptions*  pOpts;
+    tOptState* pOS;
+    char*      pzLine;
+    tDirection direction;
 {
     /*
      *  Strip off the first token on the line.
@@ -885,13 +894,13 @@ DEF_PROC_4( STATIC void loadOptionLine,
          */
         if (! SUCCESSFUL( longOptionFind( pOpts, pzLine, pOS )))
             return;
-        if (pOS->pOD->fOptState & OPTST_NO_INIT)
+        if (pOS->flags & OPTST_NO_INIT)
             return;
 
         pOS->pzOptArg = pz;
     }
 
-    switch (pOS->pOD->fOptState & (OPTST_IMM|OPTST_DISABLE_IMM)) {
+    switch (pOS->flags & (OPTST_IMM|OPTST_DISABLE_IMM)) {
     case 0:
         /*
          *  The selected option has no immediate action.
@@ -983,10 +992,11 @@ DEF_PROC_4( STATIC void loadOptionLine,
  *
  *  Load a file containing presetting information (an RC file).
  */
-DEF_PROC_3( STATIC void filePreset,
-            tOptions*,    pOpts,
-            const char*,  pzFileName,
-            int,          direction )
+STATIC void
+filePreset( pOpts, pzFileName, direction )
+    tOptions*     pOpts;
+    const char*   pzFileName;
+    int           direction;
 {
     typedef enum { SEC_NONE, SEC_LOOKING, SEC_PROCESS } teSec;
     teSec   sec     = SEC_NONE;
@@ -1095,7 +1105,7 @@ DEF_PROC_3( STATIC void filePreset,
  *  doEnvPresets - check for preset values from the envrionment
  *  This routine should process in all, immediate or normal modes....
  */
-    STATIC void
+STATIC void
 doEnvPresets( pOpts, type )
     tOptions*       pOpts;
     teEnvPresetType type;
@@ -1141,7 +1151,7 @@ doEnvPresets( pOpts, type )
         st.pzOptArg = getenv( zEnvName );
         if (st.pzOptArg == (char*)NULL)
             continue;
-        st.flags    = OPTST_PRESET;
+        st.flags    = OPTST_PRESET | st.pOD->fOptState;
         st.optType  = TOPT_UNDEFINED;
         st.argType  = 0;
 
@@ -1157,10 +1167,10 @@ doEnvPresets( pOpts, type )
              *  Process only immediate actions
              */
             if (st.flags & OPTST_DISABLED) {
-                if ((st.pOD->fOptState & OPTST_DISABLE_IMM) == 0)
+                if ((st.flags & OPTST_DISABLE_IMM) == 0)
                     continue;
             } else {
-                if ((st.pOD->fOptState & OPTST_IMM) == 0)
+                if ((st.flags & OPTST_IMM) == 0)
                     continue;
             }
             break;
@@ -1170,10 +1180,10 @@ doEnvPresets( pOpts, type )
              *  Process only NON immediate actions
              */
             if (st.flags & OPTST_DISABLED) {
-                if ((st.pOD->fOptState & OPTST_DISABLE_IMM) != 0)
+                if ((st.flags & OPTST_DISABLE_IMM) != 0)
                     continue;
             } else {
-                if ((st.pOD->fOptState & OPTST_IMM) != 0)
+                if ((st.flags & OPTST_IMM) != 0)
                     continue;
             }
             break;
@@ -1217,7 +1227,8 @@ doEnvPresets( pOpts, type )
 /*
  *  doPresets - check for preset values from an rc file or the envrionment
  */
-STATIC tSuccess doPresets( pOpts )
+STATIC tSuccess
+doPresets( pOpts )
     tOptions*  pOpts;
 {
 #   define SKIP_RC_FILES \
@@ -1328,7 +1339,8 @@ STATIC tSuccess doPresets( pOpts )
  *
  *  Make sure that the argument list passes our consistency tests.
  */
-STATIC int checkConsistency( pOpts )
+STATIC int
+checkConsistency( pOpts )
     tOptions*  pOpts;
 {
     int       errCt = 0;
@@ -1343,9 +1355,6 @@ STATIC int checkConsistency( pOpts )
      *  FOR each of "oCt" options, ...
      */
     for (;;) {
-        tSCC zNotEnough[] = "ERROR:  The %s option must appear %d times\n";
-        tSCC zNeedOne[]   = "ERROR:  The %s option is required\n";
-
         const int*  pMust = pOD->pOptMust;
         const int*  pCant = pOD->pOptCant;
 
@@ -1384,18 +1393,33 @@ STATIC int checkConsistency( pOpts )
         /*
          *  IF       this option is not equivalenced to another,
          *        OR it is equivalenced to itself (is the equiv. root)
-         *    AND it does not occur often enough
-         *  THEN note the error
+         *  THEN we need to make sure it occurrs often enough.
          */
-        if (  (  (pOD->optEquivIndex == NO_EQUIVALENT)
-              || (pOD->optEquivIndex == pOD->optIndex) )
-           && (pOD->optOccCt <  pOD->optMinCt)  )  {
+        if (  (pOD->optEquivIndex == NO_EQUIVALENT)
+           || (pOD->optEquivIndex == pOD->optIndex) )   do {
+            tSCC zNotEnough[] = "ERROR:  The %s option must appear %d times\n";
+            tSCC zNeedOne[]   = "ERROR:  The %s option is required\n";
+
+            /*
+             *  IF the occurrance counts have been satisfied,
+             *  THEN there is no problem.
+             */
+            if (pOD->optOccCt >= pOD->optMinCt)
+                break;
+
+            /*
+             *  IF presetting is okay and it has been preset,
+             *  THEN min occurrance count doesn't count
+             */
+#           define PRESET_OK  (OPTST_PRESET | OPTST_MUST_SET)
+            if ((pOD->fOptState & PRESET_OK) == PRESET_OK)
+                break;
 
             errCt++;
             if (pOD->optMinCt > 1)
                 fprintf( stderr, zNotEnough, pOD->pz_Name, pOD->optMinCt );
             else fprintf( stderr, zNeedOne, pOD->pz_Name );
-        }
+           } while (0);
 
         if (--oCt <= 0)
             break;
@@ -1444,9 +1468,9 @@ STATIC int checkConsistency( pOpts )
  *  This is a user callable routine for setting options from, for
  *  example, the contents of a file that they read in.
  */
-DEF_PROC_2( void optionLoadLine,
-            tOptions*,  pOpts,
-            char*,      pzLine )
+void optionLoadLine( pOpts, pzLine )
+    tOptions*  pOpts;
+    char*      pzLine;
 {
     tOptState st = { NULL, OPTST_SET, TOPT_UNDEFINED, 0, NULL };
     loadOptionLine( pOpts, &st, pzLine, DIRECTION_PROCESS );
@@ -1459,9 +1483,9 @@ DEF_PROC_2( void optionLoadLine,
  *  This is callable from the option descriptor.
  *  It is referenced when homerc files are enabled.
  */
-DEF_PROC_2( void doLoadOpt,
-            tOptions*,  pOpts,
-            tOptDesc*,  pOptDesc )
+void doLoadOpt( pOpts, pOptDesc )
+    tOptions*  pOpts;
+    tOptDesc*  pOptDesc;
 {
     /*
      *  IF the option is not being disabled,
@@ -1549,7 +1573,7 @@ optionProcess( pOpts, argCt, argVect )
         /*
          *  IF this is not an immediate-attribute option, then do it.
          */
-        switch (optState.pOD->fOptState & (OPTST_DISABLE_IMM|OPTST_IMM)) {
+        switch (optState.flags & (OPTST_DISABLE_IMM|OPTST_IMM)) {
         case 0:                   /* always */
             break;
 
@@ -1606,6 +1630,7 @@ optionProcess( pOpts, argCt, argVect )
 
     return pOpts->curOptIdx;
 }
+
 /*
  * Local Variables:
  * c-file-style: "stroustrup"
