@@ -1,13 +1,13 @@
 
 /*
- *  autoopts.h  $Id: autoopts.h,v 2.21 2001/09/22 18:28:26 bkorb Exp $
+ *  autoopts.h  $Id: autoopts.h,v 3.1 2001/12/10 01:13:09 bkorb Exp $
  *
  *  This file defines all the global structures and special values
  *  used in the automated option processing library.
  */
 
 /*
- *  Automated Options copyright 1992-1999 Bruce Korb
+ *  Automated Options copyright 1992-2001 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -172,7 +172,7 @@ typedef enum {
 
 typedef struct {
     tOptDesc*  pOD;
-    u_long     flags;
+    tUL        flags;
     teOptType  optType;
     int        argType;
     char*      pzOptArg;
@@ -183,53 +183,11 @@ typedef struct {
 #    define PROTO(s) s
 #  endif
 
-/*
- *  All this "DEF_PROC_*" weirdness is so that I can compile the option
- *  processing code with a K&R compiler.  Yuck.  Don't use them unless
- *  you really have to.  (Still better than ugly if-defs, tho.)
- */
-#define DEF_PROC_0( id ) \
-          id( void ); \
-          id( void )
-
-#define DEF_PROC_1( id, a1_type, a1_name ) \
-          id( a1_type a1_name ); \
-          id( a1_type a1_name )
-
-#define DEF_PROC_2( id, a1t, a1n, a2t, a2n ) \
-          id( a1t a1n, a2t a2n ); \
-          id( a1t a1n, a2t a2n )
-
-#define DEF_PROC_3( id, a1t, a1n, a2t, a2n, a3t, a3n ) \
-          id( a1t a1n, a2t a2n, a3t a3n ); \
-          id( a1t a1n, a2t a2n, a3t a3n )
-
-#define DEF_PROC_4( id, a1t, a1n, a2t, a2n, a3t, a3n, a4t, a4n ) \
-          id( a1t a1n, a2t a2n, a3t a3n, a4t a4n ); \
-          id( a1t a1n, a2t a2n, a3t a3n, a4t a4n )
-
 #else
 #  ifndef PROTO
 #    define PROTO(s) ()
 #  endif
 
-#define DEF_PROC_0( id ) \
-          id()
-
-#define DEF_PROC_1( id, a1_type, a1_name ) \
-          id( a1_name ) a1_type a1_name;
-
-#define DEF_PROC_2( id, a1t, a1n, a2t, a2n ) \
-          id( a1n, a2n ) a1t a1n; a2t a2n;
-
-#define DEF_PROC_3( id, a1t, a1n, a2t, a2n, a3t, a3n ) \
-          id( a1n, a2n, a3n ) \
-          a1t a1n; a2t a2n; a3t a3n;
-
-#define DEF_PROC_4( id, a1t, a1n, a2t, a2n, a3t, a3n, a4t, a4n ) \
-          id( a1n, a2n, a3n ) \
-          a1t a1n; a2t a2n; a3t a3n; a4t a4n;
-
 #endif
 
 #ifdef MEMDEBUG
@@ -262,14 +220,15 @@ void    optionSave PROTO((   tOptions* pOpts ));
  *  is relative to the location of the executable.
  */
 ag_bool optionMakePath PROTO((
-	char*    pzBuf,
-	size_t   bufSize,
-	tCC*     pzName,
-	tCC*     pzProgPath ));
+    char*    pzBuf,
+    size_t   bufSize,
+    tCC*     pzName,
+    tCC*     pzProgPath ));
 
 #endif /* AUTOGEN_AUTOOPTS_H */
 /*
  * Local Variables:
  * c-file-style: "stroustrup"
+ * indent-tabs-mode: nil
  * End:
  * autoopts.h ends here */
