@@ -32,10 +32,6 @@
 #  include "snprintfv/snprintfv.h"
 #endif
 
-#ifndef HAVE_STRSIGNAL
-#  include "compat/strsignal.c"
-#endif
-
 #ifdef WITH_INCLUDED_REGEX
 #  include "compat/gnu-regex.h"
 #else
